@@ -19,14 +19,12 @@ from oslo_log import log
 from pecan import rest
 
 from ironic import api
-from ironic.api.controllers import base
 from ironic.api.controllers.v1 import node as node_ctl
-from ironic.api.controllers.v1 import types
 from ironic.api.controllers.v1 import utils as api_utils
-from ironic.api import expose
+from ironic.api import method
+from ironic.common import args
 from ironic.common import exception
 from ironic.common.i18n import _
-from ironic.common import policy
 from ironic.common import states
 from ironic.common import utils
 from ironic import objects
@@ -35,11 +33,11 @@ from ironic import objects
 CONF = cfg.CONF
 LOG = log.getLogger(__name__)
 
-_LOOKUP_RETURN_FIELDS = ('uuid', 'properties', 'instance_info',
-                         'driver_internal_info')
+_LOOKUP_RETURN_FIELDS = ['uuid', 'properties', 'instance_info',
+                         'driver_internal_info']
 
 
-def config():
+def config(token):
     return {
         'metrics': {
             'backend': CONF.metrics.agent_backend,
@@ -52,28 +50,19 @@ def config():
             'statsd_host': CONF.metrics_statsd.agent_statsd_host,
             'statsd_port': CONF.metrics_statsd.agent_statsd_port
         },
-        'heartbeat_timeout': CONF.api.ramdisk_heartbeat_timeout
+        'heartbeat_timeout': CONF.api.ramdisk_heartbeat_timeout,
+        'agent_token': token,
+        # Since this is for the Victoria release, we send this as an
+        # explicit True statement for newer agents to lock the setting
+        # and behavior into place.
+        'agent_token_required': True,
     }
 
 
-class LookupResult(base.APIBase):
-    """API representation of the node lookup result."""
-
-    node = node_ctl.Node
-    """The short node representation."""
-
-    config = {str: types.jsontype}
-    """The configuration to pass to the ramdisk."""
-
-    @classmethod
-    def sample(cls):
-        return cls(node=node_ctl.Node.sample(),
-                   config={'heartbeat_timeout': 600})
-
-    @classmethod
-    def convert_with_links(cls, node):
-        node = node_ctl.Node.convert_with_links(node, _LOOKUP_RETURN_FIELDS)
-        return cls(node=node, config=config())
+def convert_with_links(node):
+    token = node.driver_internal_info.get('agent_secret_token')
+    node = node_ctl.node_convert_with_links(node, _LOOKUP_RETURN_FIELDS)
+    return {'node': node, 'config': config(token)}
 
 
 class LookupController(rest.RestController):
@@ -85,7 +74,8 @@ class LookupController(rest.RestController):
             return states.FASTTRACK_LOOKUP_ALLOWED_STATES
         return states.LOOKUP_ALLOWED_STATES
 
-    @expose.expose(LookupResult, types.listtype, types.uuid)
+    @method.expose()
+    @args.validate(addresses=args.string_list, node_uuid=args.uuid)
     def get_all(self, addresses=None, node_uuid=None):
         """Look up a node by its MAC addresses and optionally UUID.
 
@@ -104,8 +94,7 @@ class LookupController(rest.RestController):
         if not api_utils.allow_ramdisk_endpoints():
             raise exception.NotFound()
 
-        cdict = api.request.context.to_policy_values()
-        policy.authorize('baremetal:driver:ipa_lookup', cdict, cdict)
+        api_utils.check_policy('baremetal:driver:ipa_lookup')
 
         # Validate the list of MAC addresses
         if addresses is None:
@@ -149,15 +138,29 @@ class LookupController(rest.RestController):
                 and node.provision_state not in self.lookup_allowed_states):
             raise exception.NotFound()
 
-        return LookupResult.convert_with_links(node)
+        if api_utils.allow_agent_token():
+            try:
+                topic = api.request.rpcapi.get_topic_for(node)
+            except exception.NoValidHost as e:
+                e.code = http_client.BAD_REQUEST
+                raise
+
+            found_node = api.request.rpcapi.get_node_with_token(
+                api.request.context, node.uuid, topic=topic)
+        else:
+            found_node = node
+        return convert_with_links(found_node)
 
 
 class HeartbeatController(rest.RestController):
     """Controller handling heartbeats from deploy ramdisk."""
 
-    @expose.expose(None, types.uuid_or_name, str,
-                   str, status_code=http_client.ACCEPTED)
-    def post(self, node_ident, callback_url, agent_version=None):
+    @method.expose(status_code=http_client.ACCEPTED)
+    @args.validate(node_ident=args.uuid_or_name, callback_url=args.string,
+                   agent_version=args.string, agent_token=args.string,
+                   agent_verify_ca=args.string)
+    def post(self, node_ident, callback_url, agent_version=None,
+             agent_token=None, agent_verify_ca=None):
         """Process a heartbeat from the deploy ramdisk.
 
         :param node_ident: the UUID or logical name of a node.
@@ -167,6 +170,8 @@ class HeartbeatController(rest.RestController):
             before sending agent_version was introduced so agent v3.0.0 (the
             last release before sending agent_version was introduced) will be
             assumed.
+        :param agent_token: randomly generated validation token.
+        :param agent_verify_ca: TLS certificate to use to connect to the agent.
         :raises: NodeNotFound if node with provided UUID or name was not found.
         :raises: InvalidUuidOrName if node_ident is not valid name or UUID.
         :raises: NoValidHost if RPC topic for node could not be retrieved.
@@ -180,23 +185,33 @@ class HeartbeatController(rest.RestController):
             raise exception.InvalidParameterValue(
                 _('Field "agent_version" not recognised'))
 
-        cdict = api.request.context.to_policy_values()
-        policy.authorize('baremetal:node:ipa_heartbeat', cdict, cdict)
+        api_utils.check_policy('baremetal:node:ipa_heartbeat')
+
+        if (agent_verify_ca is not None
+                and not api_utils.allow_verify_ca_in_heartbeat()):
+            raise exception.InvalidParameterValue(
+                _('Field "agent_verify_ca" not recognised in this version'))
 
         rpc_node = api_utils.get_rpc_node_with_suffix(node_ident)
         dii = rpc_node['driver_internal_info']
         agent_url = dii.get('agent_url')
         # If we have an agent_url on file, and we get something different
         # we should fail because this is unexpected behavior of the agent.
-        if (agent_url is not None
-            and agent_url != callback_url):
-                LOG.error('Received heartbeat for node %(node)s with '
-                          'callback URL %(url)s. This is not expected, '
-                          'and the heartbeat will not be processed.',
-                          {'node': rpc_node.uuid, 'url': callback_url})
-                raise exception.Invalid(
-                    _('Detected change in ramdisk provided '
-                      '"callback_url"'))
+        if agent_url is not None and agent_url != callback_url:
+            LOG.error('Received heartbeat for node %(node)s with '
+                      'callback URL %(url)s. This is not expected, '
+                      'and the heartbeat will not be processed.',
+                      {'node': rpc_node.uuid, 'url': callback_url})
+            raise exception.Invalid(
+                _('Detected change in ramdisk provided '
+                  '"callback_url"'))
+        # NOTE(TheJulia): If tokens are required, lets go ahead and fail the
+        # heartbeat very early on.
+        if agent_token is None:
+            LOG.error('Agent heartbeat received for node %(node)s '
+                      'without an agent token.', {'node': node_ident})
+            raise exception.InvalidParameterValue(
+                _('Agent token is required for heartbeat processing.'))
 
         try:
             topic = api.request.rpcapi.get_topic_for(rpc_node)
@@ -206,4 +221,4 @@ class HeartbeatController(rest.RestController):
 
         api.request.rpcapi.heartbeat(
             api.request.context, rpc_node.uuid, callback_url,
-            agent_version, topic=topic)
+            agent_version, agent_token, agent_verify_ca, topic=topic)
