@@ -37,6 +37,7 @@ from ironic.common.i18n import _
 from ironic.common import policy
 from ironic.common import states
 from ironic.common import utils
+from ironic.conductor import steps as conductor_steps
 from ironic import objects
 from ironic.objects import fields as ofields
 
@@ -121,6 +122,24 @@ LOCAL_LINK_CONN_SCHEMA = {'anyOf': [
     {'type': 'object', 'additionalProperties': False},
 ]}
 
+DEPLOY_STEP_SCHEMA = {
+    'type': 'object',
+    'properties': {
+        'args': {'type': 'object'},
+        'interface': {
+            'type': 'string',
+            'enum': list(conductor_steps.DEPLOYING_INTERFACE_PRIORITY)
+        },
+        'priority': {'anyOf': [
+            {'type': 'integer', 'minimum': 0},
+            {'type': 'string', 'minLength': 1, 'pattern': '^[0-9]+$'}
+        ]},
+        'step': {'type': 'string', 'minLength': 1},
+    },
+    'required': ['interface', 'step', 'args', 'priority'],
+    'additionalProperties': False,
+}
+
 
 def local_link_normalize(name, value):
     if not value:
@@ -1458,8 +1477,11 @@ def check_policy(policy_name):
     :policy_name: Name of the policy to check.
     :raises: HTTPForbidden if the policy forbids access.
     """
+    # NOTE(lbragstad): Mapping context attributes into a target dictionary is
+    # effectively a noop from an authorization perspective because the values
+    # we're comparing are coming from the same place.
     cdict = api.request.context.to_policy_values()
-    policy.authorize(policy_name, cdict, cdict)
+    policy.authorize(policy_name, cdict, api.request.context)
 
 
 def check_owner_policy(object_type, policy_name, owner, lessee=None):
@@ -1478,7 +1500,7 @@ def check_owner_policy(object_type, policy_name, owner, lessee=None):
     target_dict[object_type + '.owner'] = owner
     if lessee:
         target_dict[object_type + '.lessee'] = lessee
-    policy.authorize(policy_name, target_dict, cdict)
+    policy.authorize(policy_name, target_dict, api.request.context)
 
 
 def check_node_policy_and_retrieve(policy_name, node_ident,
@@ -1502,7 +1524,7 @@ def check_node_policy_and_retrieve(policy_name, node_ident,
         # don't expose non-existence of node unless requester
         # has generic access to policy
         cdict = api.request.context.to_policy_values()
-        policy.authorize(policy_name, cdict, cdict)
+        policy.authorize(policy_name, cdict, api.request.context)
         raise
 
     check_owner_policy('node', policy_name,
@@ -1527,7 +1549,7 @@ def check_allocation_policy_and_retrieve(policy_name, allocation_ident):
         # don't expose non-existence unless requester
         # has generic access to policy
         cdict = api.request.context.to_policy_values()
-        policy.authorize(policy_name, cdict, cdict)
+        policy.authorize(policy_name, cdict, api.request.context)
         raise
 
     check_owner_policy('allocation', policy_name, rpc_allocation['owner'])
@@ -1571,12 +1593,13 @@ def check_list_policy(object_type, owner=None):
     cdict = api.request.context.to_policy_values()
     try:
         policy.authorize('baremetal:%s:list_all' % object_type,
-                         cdict, cdict)
+                         cdict, api.request.context)
     except exception.HTTPForbidden:
         project_owner = cdict.get('project_id')
         if (not project_owner or (owner and owner != project_owner)):
             raise
-        policy.authorize('baremetal:%s:list' % object_type, cdict, cdict)
+        policy.authorize('baremetal:%s:list' % object_type,
+                         cdict, api.request.context)
         return project_owner
     return owner
 
@@ -1599,14 +1622,14 @@ def check_port_policy_and_retrieve(policy_name, port_uuid):
     except exception.PortNotFound:
         # don't expose non-existence of port unless requester
         # has generic access to policy
-        policy.authorize(policy_name, cdict, cdict)
+        policy.authorize(policy_name, cdict, context)
         raise
 
     rpc_node = objects.Node.get_by_id(context, rpc_port.node_id)
     target_dict = dict(cdict)
     target_dict['node.owner'] = rpc_node['owner']
     target_dict['node.lessee'] = rpc_node['lessee']
-    policy.authorize(policy_name, target_dict, cdict)
+    policy.authorize(policy_name, target_dict, context)
 
     return rpc_port, rpc_node
 
@@ -1619,12 +1642,14 @@ def check_port_list_policy():
     """
     cdict = api.request.context.to_policy_values()
     try:
-        policy.authorize('baremetal:port:list_all', cdict, cdict)
+        policy.authorize('baremetal:port:list_all',
+                         cdict, api.request.context)
     except exception.HTTPForbidden:
         owner = cdict.get('project_id')
         if not owner:
             raise
-        policy.authorize('baremetal:port:list', cdict, cdict)
+        policy.authorize('baremetal:port:list',
+                         cdict, api.request.context)
         return owner
 
 
@@ -1683,3 +1708,29 @@ def allow_local_link_connection_network_type():
 def allow_verify_ca_in_heartbeat():
     """Check if heartbeat accepts agent_verify_ca."""
     return api.request.version.minor >= versions.MINOR_68_HEARTBEAT_VERIFY_CA
+
+
+def allow_deploy_steps():
+    """Check if deploy_steps are available."""
+    return api.request.version.minor >= versions.MINOR_69_DEPLOY_STEPS
+
+
+def check_allow_deploy_steps(target, deploy_steps):
+    """Check if deploy steps are allowed"""
+
+    if not deploy_steps:
+        return
+
+    if not allow_deploy_steps():
+        raise exception.NotAcceptable(_(
+            "Request not acceptable. The minimal required API version "
+            "should be %(base)s.%(opr)s") %
+            {'base': versions.BASE_VERSION,
+             'opr': versions.MINOR_69_DEPLOY_STEPS})
+
+    allowed_states = (states.ACTIVE, states.REBUILD)
+    if target not in allowed_states:
+        msg = (_('"deploy_steps" is only valid when setting target '
+                 'provision state to %s or %s') % allowed_states)
+        raise exception.ClientSideError(
+            msg, status_code=http_client.BAD_REQUEST)
