@@ -103,13 +103,15 @@ class ConductorAPI(object):
                 heartbeat
     |    1.50 - Added set_indicator_state, get_indicator_state and
     |           get_supported_indicators.
+    |    1.51 - Added agent_verify_ca to heartbeat.
+    |    1.52 - Added deploy steps argument to provisioning
 
     """
 
     # NOTE(rloo): This must be in sync with manager.ConductorManager's.
     # NOTE(pas-ha): This also must be in sync with
     #               ironic.common.release_mappings.RELEASE_MAPPING['master']
-    RPC_API_VERSION = '1.50'
+    RPC_API_VERSION = '1.52'
 
     def __init__(self, topic=None):
         super(ConductorAPI, self).__init__()
@@ -131,9 +133,8 @@ class ConductorAPI(object):
             self.client = rpc.get_client(target, version_cap=version_cap,
                                          serializer=serializer)
 
-        use_groups = self.client.can_send_version('1.47')
         # NOTE(tenbrae): this is going to be buggy
-        self.ring_manager = hash_ring.HashRingManager(use_groups=use_groups)
+        self.ring_manager = hash_ring.HashRingManager()
 
     def get_conductor_for(self, node):
         """Get the conductor which the node is mapped to.
@@ -201,6 +202,10 @@ class ConductorAPI(object):
         host = random.choice(list(ring.nodes))
         return self.topic + "." + host
 
+    def get_current_topic(self):
+        """Get RPC topic name for the current conductor."""
+        return self.topic + "." + CONF.host
+
     def can_send_create_port(self):
         """Return whether the RPCAPI supports the create_port method."""
         return self.client.can_send_version("1.41")
@@ -395,7 +400,7 @@ class ConductorAPI(object):
                           driver_name=driver_name)
 
     def do_node_deploy(self, context, node_id, rebuild, configdrive,
-                       topic=None):
+                       topic=None, deploy_steps=None):
         """Signal to conductor service to perform a deployment.
 
         :param context: request context.
@@ -403,6 +408,7 @@ class ConductorAPI(object):
         :param rebuild: True if this is a rebuild request.
         :param configdrive: A gzipped and base64 encoded configdrive.
         :param topic: RPC topic. Defaults to self.topic.
+        :param deploy_steps: Deploy steps
         :raises: InstanceDeployFailure
         :raises: InvalidParameterValue if validation fails
         :raises: MissingParameterValue if a required parameter is missing
@@ -413,9 +419,15 @@ class ConductorAPI(object):
         undeployed state before this method is called.
 
         """
-        cctxt = self.client.prepare(topic=topic or self.topic, version='1.22')
+        version = '1.22'
+        new_kws = {}
+        if deploy_steps:
+            version = '1.52'
+            new_kws['deploy_steps'] = deploy_steps
+
+        cctxt = self.client.prepare(topic=topic or self.topic, version=version)
         return cctxt.call(context, 'do_node_deploy', node_id=node_id,
-                          rebuild=rebuild, configdrive=configdrive)
+                          rebuild=rebuild, configdrive=configdrive, **new_kws)
 
     def do_node_tear_down(self, context, node_id, topic=None):
         """Signal to conductor service to tear down a deployment.
@@ -898,7 +910,7 @@ class ConductorAPI(object):
                           node_id=node_id, clean_steps=clean_steps)
 
     def heartbeat(self, context, node_id, callback_url, agent_version,
-                  agent_token=None, topic=None):
+                  agent_token=None, agent_verify_ca=None, topic=None):
         """Process a node heartbeat.
 
         :param context: request context.
@@ -907,6 +919,7 @@ class ConductorAPI(object):
         :param topic: RPC topic. Defaults to self.topic.
         :param agent_token: randomly generated validation token.
         :param agent_version: the version of the agent that is heartbeating
+        :param agent_verify_ca: TLS certificate for the agent.
         :raises: InvalidParameterValue if an invalid agent token is received.
         """
         new_kws = {}
@@ -917,6 +930,9 @@ class ConductorAPI(object):
         if self.client.can_send_version('1.49'):
             version = '1.49'
             new_kws['agent_token'] = agent_token
+        if self.client.can_send_version('1.51'):
+            version = '1.51'
+            new_kws['agent_verify_ca'] = agent_verify_ca
         cctxt = self.client.prepare(topic=topic or self.topic, version=version)
         return cctxt.call(context, 'heartbeat', node_id=node_id,
                           callback_url=callback_url, **new_kws)
