@@ -81,6 +81,17 @@ def _sorted_steps(steps, sort_step_key):
     return sorted(steps, key=sort_step_key, reverse=True)
 
 
+def is_equivalent(step1, step2):
+    """Compare steps, ignoring their priority."""
+    return (step1.get('interface') == step2.get('interface')
+            and step1.get('step') == step2.get('step'))
+
+
+def find_step(steps, step):
+    """Find an identical step in the list of steps."""
+    return next((x for x in steps if is_equivalent(x, step)), None)
+
+
 def _get_steps(task, interfaces, get_method, enabled=False,
                sort_step_key=None):
     """Get steps for task.node.
@@ -227,7 +238,7 @@ def _get_steps_from_deployment_templates(task, templates):
     return steps
 
 
-def _get_validated_steps_from_templates(task):
+def _get_validated_steps_from_templates(task, skip_missing=False):
     """Return a list of validated deploy steps from deploy templates.
 
     Deployment template steps are those steps defined in deployment templates
@@ -258,10 +269,11 @@ def _get_validated_steps_from_templates(task):
                       'deploy templates: %(templates)s. Errors: ') %
                     {'templates': ','.join(t.name for t in templates)})
     return _validate_user_deploy_steps(task, user_steps,
-                                       error_prefix=error_prefix)
+                                       error_prefix=error_prefix,
+                                       skip_missing=skip_missing)
 
 
-def _get_all_deployment_steps(task):
+def _get_all_deployment_steps(task, skip_missing=False):
     """Get deployment steps for task.node.
 
     Deployment steps from matching deployment templates are combined with those
@@ -272,11 +284,23 @@ def _get_all_deployment_steps(task):
         deploy steps.
     :returns: A list of deploy step dictionaries
     """
+    # Get deploy steps provided by user via argument if any. These steps
+    # override template and driver steps when overlap.
+    user_steps = _get_validated_user_deploy_steps(
+        task, skip_missing=skip_missing)
+
     # Gather deploy steps from deploy templates and validate.
     # NOTE(mgoddard): although we've probably just validated the templates in
     # do_node_deploy, they may have changed in the DB since we last checked, so
     # validate again.
-    user_steps = _get_validated_steps_from_templates(task)
+    template_steps = _get_validated_steps_from_templates(
+        task, skip_missing=skip_missing)
+
+    # Take only template steps that are not already provided by user
+    user_step_keys = {(s['interface'], s['step']) for s in user_steps}
+    new_template_steps = [s for s in template_steps
+                          if (s['interface'], s['step']) not in user_step_keys]
+    user_steps.extend(new_template_steps)
 
     # Gather enabled deploy steps from drivers.
     driver_steps = _get_deployment_steps(task, enabled=True, sort=False)
@@ -293,19 +317,22 @@ def _get_all_deployment_steps(task):
     return _sorted_steps(steps, _deploy_step_key)
 
 
-def set_node_deployment_steps(task):
+def set_node_deployment_steps(task, reset_current=True, skip_missing=False):
     """Set up the node with deployment step information for deploying.
 
     Get the deploy steps from the driver.
 
+    :param reset_current: Whether to reset the current step to the first one.
     :raises: InstanceDeployFailure if there was a problem getting the
              deployment steps.
     """
     node = task.node
     driver_internal_info = node.driver_internal_info
-    driver_internal_info['deploy_steps'] = _get_all_deployment_steps(task)
-    node.deploy_step = {}
-    driver_internal_info['deploy_step_index'] = None
+    driver_internal_info['deploy_steps'] = _get_all_deployment_steps(
+        task, skip_missing=skip_missing)
+    if reset_current:
+        node.deploy_step = {}
+        driver_internal_info['deploy_step_index'] = None
     node.driver_internal_info = driver_internal_info
     node.save()
 
@@ -436,8 +463,8 @@ def _validate_user_step(task, user_step, driver_step, step_type):
 
         # NOTE(mgoddard): we'll need something a little more sophisticated to
         # track core steps once we split out the single core step.
-        is_core = (driver_step['interface'] == 'deploy' and
-                   driver_step['step'] == 'deploy')
+        is_core = (driver_step['interface'] == 'deploy'
+                   and driver_step['step'] == 'deploy')
         if is_core:
             error = (_('deploy step %(step)s on interface %(interface)s is a '
                        'core step and cannot be overridden by user steps. It '
@@ -450,7 +477,7 @@ def _validate_user_step(task, user_step, driver_step, step_type):
 
 
 def _validate_user_steps(task, user_steps, driver_steps, step_type,
-                         error_prefix=None):
+                         error_prefix=None, skip_missing=False):
     """Validate the user-specified steps.
 
     :param task: A TaskManager object
@@ -506,23 +533,35 @@ def _validate_user_steps(task, user_steps, driver_steps, step_type,
     # Convert driver steps to a dict.
     driver_steps = {_step_id(s): s for s in driver_steps}
 
+    result = []
+
     for user_step in user_steps:
         # Check if this user-specified step isn't supported by the driver
         try:
             driver_step = driver_steps[_step_id(user_step)]
         except KeyError:
-            error = (_('node does not support this %(type)s step: %(step)s')
-                     % {'type': step_type, 'step': user_step})
-            errors.append(error)
+            if skip_missing:
+                LOG.debug('%(type)s step %(step)s is not currently known for '
+                          'node %(node)s, delaying its validation until '
+                          'in-band steps are loaded',
+                          {'type': step_type.capitalize(),
+                           'step': user_step, 'node': task.node.uuid})
+            else:
+                error = (_('node does not support this %(type)s step: '
+                           '%(step)s')
+                         % {'type': step_type, 'step': user_step})
+                errors.append(error)
             continue
 
         step_errors = _validate_user_step(task, user_step, driver_step,
                                           step_type)
         errors.extend(step_errors)
+        result.append(user_step)
 
     if step_type == 'deploy':
-        # Deploy steps should be unique across all combined templates.
-        dup_errors = _validate_deploy_steps_unique(user_steps)
+        # Deploy steps should be unique across all combined templates or passed
+        # deploy_steps argument.
+        dup_errors = _validate_deploy_steps_unique(result)
         errors.extend(dup_errors)
 
     if errors:
@@ -530,7 +569,7 @@ def _validate_user_steps(task, user_steps, driver_steps, step_type,
         err += '; '.join(errors)
         raise exception.InvalidParameterValue(err=err)
 
-    return user_steps
+    return result
 
 
 def _validate_user_clean_steps(task, user_steps):
@@ -558,7 +597,8 @@ def _validate_user_clean_steps(task, user_steps):
     return _validate_user_steps(task, user_steps, driver_steps, 'clean')
 
 
-def _validate_user_deploy_steps(task, user_steps, error_prefix=None):
+def _validate_user_deploy_steps(task, user_steps, error_prefix=None,
+                                skip_missing=False):
     """Validate the user-specified deploy steps.
 
     :param task: A TaskManager object
@@ -585,17 +625,53 @@ def _validate_user_deploy_steps(task, user_steps, error_prefix=None):
     """
     driver_steps = _get_deployment_steps(task, enabled=False, sort=False)
     return _validate_user_steps(task, user_steps, driver_steps, 'deploy',
-                                error_prefix=error_prefix)
+                                error_prefix=error_prefix,
+                                skip_missing=skip_missing)
 
 
-def validate_deploy_templates(task):
-    """Validate the deploy templates for a node.
+def _get_validated_user_deploy_steps(task, deploy_steps=None,
+                                     skip_missing=False):
+    """Validate the deploy steps for a node.
 
     :param task: A TaskManager object
+    :param deploy_steps: Deploy steps to validate. Optional. If not provided
+        then will check node's driver internal info.
+    :param skip_missing: whether skip missing steps that are not yet available
+        at the time of validation.
+    :raises: InvalidParameterValue if deploy steps are unsupported by the
+        node's driver interfaces.
+    :raises: InstanceDeployFailure if there was a problem getting the deploy
+        steps from the driver.
+    """
+    if not deploy_steps:
+        deploy_steps = task.node.driver_internal_info.get('user_deploy_steps')
+
+    if deploy_steps:
+        error_prefix = (_('Validation of deploy steps from "deploy steps" '
+                          'argument failed.'))
+        return _validate_user_deploy_steps(task, deploy_steps,
+                                           error_prefix=error_prefix,
+                                           skip_missing=skip_missing)
+    else:
+        return []
+
+
+def validate_user_deploy_steps_and_templates(task, deploy_steps=None,
+                                             skip_missing=False):
+    """Validate the user deploy steps and the deploy templates for a node.
+
+    :param task: A TaskManager object
+    :param deploy_steps: Deploy steps to validate. Optional. If not provided
+        then will check node's driver internal info.
+    :param skip_missing: whether skip missing steps that are not yet available
+        at the time of validation.
     :raises: InvalidParameterValue if the instance has traits that map to
-        deploy steps that are unsupported by the node's driver interfaces.
+        deploy steps that are unsupported by the node's driver interfaces or
+        user deploy steps are unsupported by the node's driver interfaces
     :raises: InstanceDeployFailure if there was a problem getting the deploy
         steps from the driver.
     """
     # Gather deploy steps from matching deploy templates and validate them.
-    _get_validated_steps_from_templates(task)
+    _get_validated_steps_from_templates(task, skip_missing=skip_missing)
+    # Validate steps from passed argument or stored on the node.
+    _get_validated_user_deploy_steps(task, deploy_steps, skip_missing)
