@@ -26,6 +26,7 @@ from oslo_log import log
 from oslo_serialization import jsonutils
 from oslo_service import loopingcall
 from oslo_utils import excutils
+from oslo_utils import strutils
 from oslo_utils import timeutils
 
 from ironic.common import boot_devices
@@ -67,10 +68,22 @@ def node_set_boot_device(task, device, persistent=False):
 
     """
     task.driver.management.validate(task)
-    if task.node.provision_state != states.ADOPTING:
-        task.driver.management.set_boot_device(task,
-                                               device=device,
-                                               persistent=persistent)
+    if task.node.provision_state == states.ADOPTING:
+        return
+
+    force_persistent = task.node.driver_info.get(
+        'force_persistent_boot_device')
+    if force_persistent == 'Always':
+        persistent = True
+    elif force_persistent == 'Never':
+        persistent = False
+    elif force_persistent not in (None, 'Default'):
+        # Backward compatibility (used to be a boolean and only True mattered)
+        if strutils.bool_from_string(force_persistent, strict=False):
+            persistent = True
+
+    task.driver.management.set_boot_device(task, device=device,
+                                           persistent=persistent)
 
 
 def node_get_boot_mode(task):
@@ -407,9 +420,9 @@ def cleanup_cleanwait_timeout(task):
 
 
 def cleaning_error_handler(task, logmsg, errmsg=None, traceback=False,
-                           tear_down_cleaning=True,
-                           set_fail_state=True):
-    """Put a failed node in CLEANFAIL and maintenance.
+                           tear_down_cleaning=True, set_fail_state=True,
+                           set_maintenance=None):
+    """Put a failed node in CLEANFAIL and maintenance (if needed).
 
     :param task: a TaskManager instance.
     :param logmsg: Message to be logged.
@@ -420,12 +433,19 @@ def cleaning_error_handler(task, logmsg, errmsg=None, traceback=False,
         cleaning. Default to True.
     :param set_fail_state: Whether to set node to failed state. Default to
         True.
+    :param set_maintenance: Whether to set maintenance mode. If None,
+        maintenance mode will be set if and only if a clean step is being
+        executed on a node.
     """
+    if set_maintenance is None:
+        set_maintenance = bool(task.node.clean_step)
+
     errmsg = errmsg or logmsg
     LOG.error(logmsg, exc_info=traceback)
     node = task.node
-    node.fault = faults.CLEAN_FAILURE
-    node.maintenance = True
+    if set_maintenance:
+        node.fault = faults.CLEAN_FAILURE
+        node.maintenance = True
 
     if tear_down_cleaning:
         try:
@@ -457,7 +477,7 @@ def cleaning_error_handler(task, logmsg, errmsg=None, traceback=False,
     manual_clean = node.target_provision_state == states.MANAGEABLE
     node.last_error = errmsg
     # NOTE(dtantsur): avoid overwriting existing maintenance_reason
-    if not node.maintenance_reason:
+    if not node.maintenance_reason and set_maintenance:
         node.maintenance_reason = errmsg
     node.save()
 
@@ -503,6 +523,7 @@ def wipe_deploy_internal_info(task):
     # Clear any leftover metadata about deployment.
     info = task.node.driver_internal_info
     info['deploy_steps'] = None
+    info.pop('user_deploy_steps', None)
     info.pop('agent_cached_deploy_steps', None)
     info.pop('deploy_step_index', None)
     info.pop('deployment_reboot', None)
@@ -1035,6 +1056,11 @@ def agent_is_alive(node, timeout=None):
     :param node: A node object.
     :param timeout: Heartbeat timeout, defaults to `fast_track_timeout`.
     """
+    # If no agent_url is present then we have powered down since the
+    # last agent heartbeat
+    if not node.driver_internal_info.get('agent_url'):
+        return False
+
     return value_within_timeout(
         node.driver_internal_info.get('agent_last_heartbeat'),
         timeout or CONF.deploy.fast_track_timeout)
@@ -1352,3 +1378,36 @@ def node_cache_bios_settings(task, node):
         msg = (_('Caching of bios settings failed on node %(node)s.')
                % {'node': node.uuid})
         LOG.exception(msg)
+
+
+def node_cache_vendor(task):
+    """Cache the vendor if it can be detected."""
+    properties = task.node.properties
+    if properties.get('vendor'):
+        return  # assume that vendors don't change on fly
+
+    try:
+        # We have no vendor stored, so we'll go ahead and
+        # call to store it.
+        vendor = task.driver.management.detect_vendor(task)
+        if not vendor:
+            return
+
+        # This function may be called without an exclusive lock, so get one
+        task.upgrade_lock(purpose='caching node vendor')
+    except exception.UnsupportedDriverExtension:
+        return
+    except Exception as exc:
+        LOG.warning('Unexpected exception when trying to detect vendor '
+                    'for node %(node)s. %(class)s: %(exc)s',
+                    {'node': task.node.uuid,
+                     'class': type(exc).__name__, 'exc': exc},
+                    exc_info=not isinstance(exc, exception.IronicException))
+        return
+
+    props = task.node.properties
+    props['vendor'] = vendor
+    task.node.properties = props
+    task.node.save()
+    LOG.info("Detected vendor %(vendor)s for node %(node)s",
+             {'vendor': vendor, 'node': task.node.uuid})
