@@ -99,6 +99,11 @@ _FASTTRACK_HEARTBEAT_ALLOWED = (states.DEPLOYWAIT, states.CLEANWAIT,
 FASTTRACK_HEARTBEAT_ALLOWED = frozenset(_FASTTRACK_HEARTBEAT_ALLOWED)
 
 
+def _get_client():
+    client = agent_client.AgentClient()
+    return client
+
+
 @METRICS.timer('post_clean_step_hook')
 def post_clean_step_hook(interface, step):
     """Decorator method for adding a post clean step hook.
@@ -367,7 +372,7 @@ def execute_step(task, step, step_type, client=None):
         completed async
     """
     if client is None:
-        client = agent_client.get_client(task)
+        client = _get_client()
     ports = objects.Port.list_by_node_id(
         task.context, task.node.id)
     call = getattr(client, 'execute_%s_step' % step_type)
@@ -405,9 +410,8 @@ class HeartbeatMixin(object):
     more of the deployment flow is driven by deploy steps.
     """
 
-    collect_deploy_logs = True
-
     def __init__(self):
+        self._client = _get_client()
         if not self.has_decomposed_deploy_steps:
             LOG.warning('%s does not support decomposed deploy steps. This '
                         'is deprecated and will stop working in a future '
@@ -560,7 +564,7 @@ class HeartbeatMixin(object):
             # Do not call the error handler is the node is already DEPLOYFAIL
             if node.provision_state in (states.DEPLOYING, states.DEPLOYWAIT):
                 deploy_utils.set_failed_state(
-                    task, last_error, collect_logs=self.collect_deploy_logs)
+                    task, last_error, collect_logs=bool(self._client))
 
     def _heartbeat_clean_wait(self, task):
         node = task.node
@@ -674,8 +678,7 @@ class HeartbeatMixin(object):
         """
         node = task.node
         try:
-            client = agent_client.get_client(task)
-            result = client.finalize_rescue(node)
+            result = self._client.finalize_rescue(node)
         except exception.IronicException as e:
             raise exception.InstanceRescueFailure(node=node.uuid,
                                                   instance=node.instance_uuid,
@@ -896,8 +899,7 @@ class AgentDeployMixin(HeartbeatMixin, AgentOobStepsMixin):
                   {'node': node.uuid, 'type': step_type,
                    'steps': previous_steps})
 
-        client = agent_client.get_client(task)
-        call = getattr(client, 'get_%s_steps' % step_type)
+        call = getattr(self._client, 'get_%s_steps' % step_type)
         try:
             agent_result = call(node, task.ports).get('command_result', {})
         except exception.AgentInProgress as exc:
@@ -1081,8 +1083,7 @@ class AgentDeployMixin(HeartbeatMixin, AgentOobStepsMixin):
         assert step_type in ('clean', 'deploy')
 
         node = task.node
-        client = agent_client.get_client(task)
-        agent_commands = client.get_commands_status(task.node)
+        agent_commands = self._client.get_commands_status(task.node)
 
         if _freshly_booted(agent_commands, step_type):
             field = ('cleaning_reboot' if step_type == 'clean'
@@ -1190,17 +1191,16 @@ class AgentDeployMixin(HeartbeatMixin, AgentOobStepsMixin):
         can_power_on = (states.POWER_ON in
                         task.driver.power.get_supported_power_states(task))
 
-        client = agent_client.get_client(task)
         try:
             if not can_power_on:
                 LOG.info('Power interface of node %(node)s does not support '
                          'power on, using reboot to switch to the instance',
                          node.uuid)
-                client.sync(node)
+                self._client.sync(node)
                 manager_utils.node_power_action(task, states.REBOOT)
             elif not oob_power_off:
                 try:
-                    client.power_off(node)
+                    self._client.power_off(node)
                 except Exception as e:
                     LOG.warning('Failed to soft power off node %(node_uuid)s. '
                                 '%(cls)s: %(error)s',
@@ -1223,7 +1223,7 @@ class AgentDeployMixin(HeartbeatMixin, AgentOobStepsMixin):
                     manager_utils.node_power_action(task, states.POWER_OFF)
             else:
                 # Flush the file system prior to hard rebooting the node
-                result = client.sync(node)
+                result = self._client.sync(node)
                 error = result.get('faultstring')
                 if error:
                     if 'Unknown command' in error:
@@ -1335,26 +1335,29 @@ class AgentDeployMixin(HeartbeatMixin, AgentOobStepsMixin):
         # image's metadata (via Glance). Fall back to the driver internal
         # info in case it is not available (e.g. not set or there's no Glance).
         if software_raid:
-            image_source = node.instance_info.get('image_source')
-            try:
-                context = task.context
-                context.is_admin = True
-                glance = image_service.GlanceImageService(
-                    context=context)
-                image_info = glance.show(image_source)
-                image_properties = image_info.get('properties')
-                root_uuid = image_properties['rootfs_uuid']
-                LOG.debug('Got rootfs_uuid from Glance: %s '
-                          '(node %s)', root_uuid, node.uuid)
-            except Exception as e:
-                LOG.warning('Could not get \'rootfs_uuid\' property for '
-                            'image %(image)s from Glance for node %(node)s. '
-                            '%(cls)s: %(error)s.',
-                            {'image': image_source, 'node': node.uuid,
-                             'cls': e.__class__.__name__, 'error': e})
-                root_uuid = internal_info.get('root_uuid_or_disk_id')
-                LOG.debug('Got rootfs_uuid from driver internal info: '
-                          '%s (node %s)', root_uuid, node.uuid)
+            root_uuid = node.instance_info.get('image_rootfs_uuid')
+            if not root_uuid:
+                image_source = node.instance_info.get('image_source')
+                try:
+                    context = task.context
+                    context.is_admin = True
+                    glance = image_service.GlanceImageService(
+                        context=context)
+                    image_info = glance.show(image_source)
+                    image_properties = image_info.get('properties')
+                    root_uuid = image_properties['rootfs_uuid']
+                    LOG.debug('Got rootfs_uuid from Glance: %s '
+                              '(node %s)', root_uuid, node.uuid)
+                except Exception as e:
+                    LOG.warning(
+                        'Could not get \'rootfs_uuid\' property for '
+                        'image %(image)s from Glance for node %(node)s. '
+                        '%(cls)s: %(error)s.',
+                        {'image': image_source, 'node': node.uuid,
+                         'cls': e.__class__.__name__, 'error': e})
+                    root_uuid = internal_info.get('root_uuid_or_disk_id')
+                    LOG.debug('Got rootfs_uuid from driver internal info: '
+                              '%s (node %s)', root_uuid, node.uuid)
 
         # For whole disk images it is not necessary that the root_uuid
         # be provided since the bootloaders on the disk will be used
@@ -1366,8 +1369,7 @@ class AgentDeployMixin(HeartbeatMixin, AgentOobStepsMixin):
                       'partition %(part)s, EFI system partition %(efi)s',
                       {'node': node.uuid, 'part': root_uuid,
                        'efi': efi_system_part_uuid})
-            client = agent_client.get_client(task)
-            result = client.install_bootloader(
+            result = self._client.install_bootloader(
                 node, root_uuid=root_uuid,
                 efi_system_part_uuid=efi_system_part_uuid,
                 prep_boot_part_uuid=prep_boot_part_uuid,
