@@ -356,7 +356,13 @@ def get_disk_label(node):
     :returns: the disk label or None if no disk label was specified.
     """
     capabilities = utils.parse_instance_info_capabilities(node)
-    return capabilities.get('disk_label')
+    label = capabilities.get('disk_label')
+    # NOTE(TheJulia): If the node is UEFI based, we should likely just default
+    # the table type to gpt as otherwise we rely upon the user to supply the
+    # right information, and for UEFI mode bios may work, but is wrong.
+    if label is None and boot_mode_utils.get_boot_mode(node) == 'uefi':
+        label = 'gpt'
+    return label
 
 
 def get_pxe_boot_file(node):
@@ -649,6 +655,9 @@ def prepare_inband_cleaning(task, manage_boot=True):
         ramdisk_opts = build_agent_options(task.node)
         task.driver.boot.prepare_ramdisk(task, ramdisk_opts)
 
+    # NOTE(dtantsur): calling prepare_ramdisk may power off the node, so we
+    # need to check fast-track again and reboot if needed.
+    fast_track = manager_utils.is_fast_track(task)
     if not fast_track:
         manager_utils.node_power_action(task, states.REBOOT)
 
