@@ -37,6 +37,7 @@ from ironic.drivers.modules.ilo import common as ilo_common
 from ironic.drivers.modules import image_utils
 from ironic.drivers.modules import ipxe
 from ironic.drivers.modules import pxe
+from ironic.drivers import utils as driver_utils
 
 LOG = logging.getLogger(__name__)
 
@@ -318,9 +319,9 @@ def prepare_node_for_deploy(task):
         # not provided.
         # Since secure boot was disabled, we are in 'uefi' boot mode.
         if boot_mode_utils.get_boot_mode_for_deploy(task.node) is None:
-            instance_info = task.node.instance_info
-            instance_info['deploy_boot_mode'] = 'uefi'
-            task.node.instance_info = instance_info
+            driver_internal_info = task.node.driver_internal_info
+            driver_internal_info['deploy_boot_mode'] = 'uefi'
+            task.node.driver_internal_info = driver_internal_info
             task.node.save()
 
 
@@ -350,7 +351,7 @@ class IloVirtualMediaBoot(base.BootInterface):
         # TODO(stendulker): COMMON_PROPERTIES should also include rescue
         # related properties (RESCUE_PROPERTIES). We can add them in Rocky,
         # when classic drivers get removed.
-        return COMMON_PROPERTIES
+        return dict(driver_utils.OPTIONAL_PROPERTIES, **COMMON_PROPERTIES)
 
     @METRICS.timer('IloVirtualMediaBoot.validate')
     def validate(self, task):
@@ -456,7 +457,8 @@ class IloVirtualMediaBoot(base.BootInterface):
         task.node.save()
 
         deploy_nic_mac = deploy_utils.get_single_nic_with_vif_port_id(task)
-        ramdisk_params['BOOTIF'] = deploy_nic_mac
+        if deploy_nic_mac is not None:
+            ramdisk_params['BOOTIF'] = deploy_nic_mac
         if (node.driver_info.get('ilo_rescue_iso')
                 and node.provision_state == states.RESCUING):
             iso = node.driver_info['ilo_rescue_iso']
@@ -1077,7 +1079,8 @@ class IloUefiHttpsBoot(base.BootInterface):
         task.node.save()
 
         deploy_nic_mac = deploy_utils.get_single_nic_with_vif_port_id(task)
-        ramdisk_params['BOOTIF'] = deploy_nic_mac
+        if deploy_nic_mac is not None:
+            ramdisk_params['BOOTIF'] = deploy_nic_mac
 
         mode = 'deploy'
         if node.provision_state == states.RESCUING:
@@ -1140,6 +1143,8 @@ class IloUefiHttpsBoot(base.BootInterface):
             LOG.debug("Node %(node)s is set to permanently boot from local "
                       "%(device)s", {'node': task.node.uuid,
                                      'device': boot_devices.DISK})
+            # Need to enable secure boot, if being requested
+            ilo_common.update_secure_boot_mode(task, True)
             return
 
         params = {}
@@ -1152,6 +1157,8 @@ class IloUefiHttpsBoot(base.BootInterface):
                     "node %s. Booting instance from disk anyway.", node.uuid)
                 manager_utils.node_set_boot_device(task, boot_devices.DISK,
                                                    persistent=True)
+                # Need to enable secure boot, if being requested
+                ilo_common.update_secure_boot_mode(task, True)
 
                 return
             params.update(root_uuid=root_uuid)
@@ -1165,6 +1172,8 @@ class IloUefiHttpsBoot(base.BootInterface):
             node.instance_info = i_info
             node.save()
 
+        # Need to enable secure boot, if being requested
+        ilo_common.update_secure_boot_mode(task, True)
         ilo_common.setup_uefi_https(task, iso_ref, persistent=True)
 
         LOG.debug("Node %(node)s is set to boot from UEFIHTTP "
@@ -1184,6 +1193,7 @@ class IloUefiHttpsBoot(base.BootInterface):
                   "%(node)s", {'node': task.node.uuid})
 
         image_utils.cleanup_iso_image(task)
+        disable_secure_boot_if_supported(task)
 
     @METRICS.timer('IloUefiHttpsBoot.validate_rescue')
     def validate_rescue(self, task):
