@@ -19,14 +19,13 @@ Common functionalities shared between different iLO modules.
 import os
 import shutil
 import tempfile
+from urllib import parse as urlparse
 
 from ironic_lib import utils as ironic_utils
 from oslo_log import log as logging
 from oslo_utils import fileutils
 from oslo_utils import importutils
-import six
-import six.moves.urllib.parse as urlparse
-from six.moves.urllib.parse import urljoin
+from oslo_utils import strutils
 
 from ironic.common import boot_devices
 from ironic.common import exception
@@ -58,7 +57,17 @@ REQUIRED_PROPERTIES = {
 OPTIONAL_PROPERTIES = {
     'client_port': _("port to be used for iLO operations. Optional."),
     'client_timeout': _("timeout (in seconds) for iLO operations. Optional."),
-    'ca_file': _("CA certificate file to validate iLO. Optional")
+    'ca_file': _("CA certificate file to validate iLO. This "
+                 "attibute is deprecated and will be removed in "
+                 "future release. Optional"),
+    'ilo_verify_ca': _("Either a Boolean value, a path to a CA_BUNDLE "
+                       "file or directory with certificates of trusted "
+                       "CAs. If set to True the driver will verify the "
+                       "host certificates; if False the driver will ignore "
+                       "verifying the SSL certificate. If it\'s a path the "
+                       "driver will use the specified certificate or one of "
+                       "the certificates in the directory. Defaults to True. "
+                       "Optional")
 }
 
 SNMP_PROPERTIES = {
@@ -118,6 +127,15 @@ POST_INPOSTDISCOVERY_STATE = "InPostDiscoveryComplete"
 POST_FINISHEDPOST_STATE = "FinishedPost"
 """ Node is in FinishedPost post state."""
 
+SUPPORTED_BOOT_MODE_LEGACY_BIOS_ONLY = 'legacy bios only'
+""" Node supports only legacy BIOS boot mode."""
+
+SUPPORTED_BOOT_MODE_UEFI_ONLY = 'uefi only'
+""" Node supports only UEFI boot mode."""
+
+SUPPORTED_BOOT_MODE_LEGACY_BIOS_AND_UEFI = 'legacy bios and uefi'
+""" Node supports both legacy BIOS and UEFI boot mode."""
+
 
 def copy_image_to_web_server(source_file_path, destination):
     """Copies the given image to the http web server.
@@ -137,7 +155,7 @@ def copy_image_to_web_server(source_file_path, destination):
 
     """
 
-    image_url = urljoin(CONF.deploy.http_url, destination)
+    image_url = urlparse.urljoin(CONF.deploy.http_url, destination)
     image_path = os.path.join(CONF.deploy.http_root, destination)
     try:
         shutil.copyfile(source_file_path, image_path)
@@ -248,22 +266,8 @@ def parse_driver_info(node):
             "The following required iLO parameters are missing from the "
             "node's driver_info: %s") % missing_info)
 
-    not_integers = []
-    for param in OPTIONAL_PROPERTIES:
-        value = info.get(param, CONF.ilo.get(param))
-        if param == "client_port":
-            d_info[param] = utils.validate_network_port(value, param)
-        elif param == "ca_file":
-            if value and not os.path.isfile(value):
-                raise exception.InvalidParameterValue(_(
-                    '%(param)s "%(value)s" is not found.') %
-                    {'param': param, 'value': value})
-            d_info[param] = value
-        else:
-            try:
-                d_info[param] = int(value)
-            except ValueError:
-                not_integers.append(param)
+    optional_info = _parse_optional_driver_info(node)
+    d_info.update(optional_info)
 
     snmp_info = _parse_snmp_driver_info(info)
     if snmp_info:
@@ -277,11 +281,6 @@ def parse_driver_info(node):
             if param == "console_port":
                 d_info[param] = utils.validate_network_port(value, param)
 
-    if not_integers:
-        raise exception.InvalidParameterValue(_(
-            "The following iLO parameters from the node's driver_info "
-            "should be integers: %s") % not_integers)
-
     return d_info
 
 
@@ -313,7 +312,7 @@ def _parse_snmp_driver_info(info):
         for param in SNMP_OPTIONAL_PROPERTIES:
             value = None
             try:
-                value = six.text_type(info[param]).upper()
+                value = str(info[param]).upper()
             except KeyError:
                 pass
             if value:
@@ -328,6 +327,75 @@ def _parse_snmp_driver_info(info):
     return snmp_info
 
 
+def _parse_optional_driver_info(node):
+    """Parses the optional driver_info parameters.
+
+    :param node: an ironic Node object.
+    :returns: a dictionary containing information of optional properties.
+    :raises: InvalidParameterValue if any parameters are incorrect
+    """
+    info = node.driver_info
+    optional_info = {}
+    not_integers = []
+
+    for param in OPTIONAL_PROPERTIES:
+        if param != 'ilo_verify_ca':
+            value = info.get(param, CONF.ilo.get(param))
+
+        if param == "client_port":
+            optional_info[param] = utils.validate_network_port(value, param)
+        elif param == "client_timeout":
+            try:
+                optional_info[param] = int(value)
+            except ValueError:
+                not_integers.append(param)
+
+    if not_integers:
+        raise exception.InvalidParameterValue(_(
+            "The following iLO parameters from the node's driver_info "
+            "should be integers: %s") % not_integers)
+
+    ca_file_value = info.get('ca_file', CONF.ilo.get('ca_file'))
+    verify_ca = info.get('ilo_verify_ca', CONF.ilo.get('verify_ca'))
+
+    if ca_file_value:
+        LOG.warning("The `driver_info/ca_file` parameter is deprecated "
+                    "in favor of `driver_info/ilo_verify_ca` parameter. "
+                    "Please use `driver_info/ilo_verify_ca` instead of "
+                    "`driver_info/ca_file` in node %(node)s "
+                    "configuration.", {'node': node.uuid})
+
+        if not os.path.isfile(ca_file_value):
+            raise exception.InvalidParameterValue(_(
+                'ca_file "%(value)s" is not found.') %
+                {'value': ca_file_value})
+        optional_info['verify_ca'] = ca_file_value
+    else:
+        # Check if ilo_verify_ca is a Boolean or a file/directory
+        # in the file-system
+        if isinstance(verify_ca, str):
+            if not os.path.isdir(verify_ca) and not os.path.isfile(verify_ca):
+                try:
+                    verify_ca = strutils.bool_from_string(verify_ca,
+                                                          strict=True)
+                except ValueError:
+                    raise exception.InvalidParameterValue(
+                        _('Invalid value type set in driver_info/'
+                          'ilo_verify_ca on node %(node)s. '
+                          'The value should be a Boolean or the path '
+                          'to a file/directory, not "%(value)s"'
+                          ) % {'value': verify_ca, 'node': node.uuid})
+        elif not isinstance(verify_ca, bool):
+            raise exception.InvalidParameterValue(
+                _('Invalid value type set in driver_info/ilo_verify_ca '
+                  'on node %(node)s. The value should be a Boolean '
+                  'or the path to a file/directory, not "%(value)s"'
+                  ) % {'value': verify_ca, 'node': node.uuid})
+        optional_info['verify_ca'] = verify_ca
+
+    return optional_info
+
+
 def get_ilo_object(node):
     """Gets an IloClient object from proliantutils library.
 
@@ -362,7 +430,7 @@ def get_ilo_object(node):
                                       driver_info['ilo_password'],
                                       driver_info['client_timeout'],
                                       driver_info['client_port'],
-                                      cacert=driver_info.get('ca_file'),
+                                      cacert=driver_info['verify_ca'],
                                       snmp_credentials=info)
     return ilo_object
 
@@ -494,6 +562,24 @@ def set_boot_mode(node, boot_mode):
              {'uuid': node.uuid, 'boot_mode': boot_mode})
 
 
+def get_current_boot_mode(node):
+    """Get the current boot mode for a node.
+
+    :param node: an ironic node object.
+    :raises: IloOperationError if failed to fetch boot mode.
+    :raises: IloOperationNotSupported if node does not support getting pending
+             boot mode.
+    """
+    ilo_object = get_ilo_object(node)
+    operation = _("Get current boot mode")
+    try:
+        c_boot_mode = ilo_object.get_current_boot_mode()
+        return BOOT_MODE_ILO_TO_GENERIC[c_boot_mode.lower()]
+    except ilo_error.IloError as ilo_exception:
+        raise exception.IloOperationError(operation=operation,
+                                          error=ilo_exception)
+
+
 def update_boot_mode(task):
     """Update instance_info with boot mode to be used for deploy.
 
@@ -511,9 +597,9 @@ def update_boot_mode(task):
     # No boot mode found. Check if default_boot_mode is defined
     if not boot_mode and (CONF.ilo.default_boot_mode in ['bios', 'uefi']):
         boot_mode = CONF.ilo.default_boot_mode
-        instance_info = node.instance_info
-        instance_info['deploy_boot_mode'] = boot_mode
-        node.instance_info = instance_info
+        driver_internal_info = node.driver_internal_info
+        driver_internal_info['deploy_boot_mode'] = boot_mode
+        node.driver_internal_info = driver_internal_info
         node.save()
 
     # Boot mode is computed, setting it for the deploy
@@ -553,13 +639,13 @@ def update_boot_mode(task):
                   "as pending boot mode is unknown.",
                   {'uuid': node.uuid, 'boot_mode': boot_mode})
 
-    instance_info = node.instance_info
-    instance_info['deploy_boot_mode'] = boot_mode
-    node.instance_info = instance_info
+    driver_internal_info = node.driver_internal_info
+    driver_internal_info['deploy_boot_mode'] = boot_mode
+    node.driver_internal_info = driver_internal_info
     node.save()
 
 
-def setup_vmedia(task, iso, ramdisk_options):
+def setup_vmedia(task, iso, ramdisk_options=None):
     """Attaches virtual media and sets it as boot device.
 
     This method attaches the given bootable ISO as virtual media, prepares the
@@ -781,7 +867,7 @@ def remove_single_or_list_of_files(file_location):
         for location in file_location:
             ironic_utils.unlink_without_raise(location)
     # file_location is a single file path
-    elif isinstance(file_location, six.string_types):
+    elif isinstance(file_location, str):
         ironic_utils.unlink_without_raise(file_location)
 
 
@@ -836,3 +922,49 @@ def get_server_post_state(node):
     except ilo_error.IloError as ilo_exception:
         raise exception.IloOperationError(operation=operation,
                                           error=ilo_exception)
+
+
+def setup_uefi_https(task, iso, persistent=False):
+    """Sets up system to boot from UEFIHTTP boot device.
+
+    Sets the one-time/persistent boot device to UEFIHTTP based
+    on the argument supplied.
+
+    :param task: a TaskManager instance containing the node to act on.
+    :param iso: ISO URL to be set to boot from.
+    :param persistent: Indicates whether the system should be set to boot
+        from the given device one-time or each time.
+    :raises: IloOperationError on an error from IloClient library.
+    :raises: IloOperationNotSupported if retrieving post state is not
+        supported on the server.
+    """
+    node = task.node
+    ilo_object = get_ilo_object(node)
+    scheme = urlparse.urlparse(iso).scheme.lower()
+
+    operation = (_("Setting up node %(node)s to boot from URL %(iso)s.") %
+                 {'iso': iso, 'node': node.uuid})
+
+    if scheme != 'https':
+        msg = (_('Error setting up node %(node)s to boot from '
+                 'URL %(iso)s. A secure URL is expected that is exposed '
+                 'over HTTPS.') %
+               {'node': node.uuid, 'iso': iso})
+        raise exception.IloOperationNotSupported(operation=operation,
+                                                 error=msg)
+
+    try:
+        ilo_object.set_http_boot_url(iso)
+        LOG.info("Set the node %(node)s to boot from URL %(iso)s "
+                 "successfully.", {'node': node.uuid, 'iso': iso})
+        if not persistent:
+            ilo_object.set_one_time_boot('UEFIHTTP')
+        else:
+            ilo_object.update_persistent_boot(['UEFIHTTP'])
+
+    except ilo_error.IloCommandNotSupportedInBiosError as ilo_exception:
+        raise exception.IloOperationNotSupported(operation=operation,
+                                                 error=ilo_exception)
+    except ilo_error.IloError as ilo_exception:
+        raise exception.IloOperationError(operation=operation,
+                                          error=ilo_exception)
