@@ -15,39 +15,27 @@ Tests for the API /allocations/ methods.
 
 import datetime
 from http import client as http_client
+from unittest import mock
 from urllib import parse as urlparse
 
 import fixtures
-import mock
 from oslo_config import cfg
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
 
 from ironic.api.controllers import base as api_base
 from ironic.api.controllers import v1 as api_v1
-from ironic.api.controllers.v1 import allocation as api_allocation
 from ironic.api.controllers.v1 import notification_utils
-from ironic.api import types as atypes
 from ironic.common import exception
 from ironic.common import policy
 from ironic.conductor import rpcapi
 from ironic import objects
 from ironic.objects import fields as obj_fields
-from ironic.tests import base
 from ironic.tests.unit.api import base as test_api_base
 from ironic.tests.unit.api import utils as apiutils
 from ironic.tests.unit.objects import utils as obj_utils
 
 
-class TestAllocationObject(base.TestCase):
-
-    def test_allocation_init(self):
-        allocation_dict = apiutils.allocation_post_data(node_id=None)
-        del allocation_dict['extra']
-        allocation = api_allocation.Allocation(**allocation_dict)
-        self.assertEqual(atypes.Unset, allocation.extra)
-
-
 class TestListAllocations(test_api_base.BaseApiTest):
     headers = {api_base.Version.string: str(api_v1.max_version())}
 
@@ -114,7 +102,7 @@ class TestListAllocations(test_api_base.BaseApiTest):
             '/allocations/%s?fields=%s' % (allocation.uuid, fields),
             headers=self.headers)
         # We always append "links"
-        self.assertItemsEqual(['resource_class', 'extra', 'links'], data)
+        self.assertCountEqual(['resource_class', 'extra', 'links'], data)
 
     def test_get_collection_custom_fields(self):
         fields = 'uuid,extra'
@@ -132,7 +120,7 @@ class TestListAllocations(test_api_base.BaseApiTest):
         self.assertEqual(3, len(data['allocations']))
         for allocation in data['allocations']:
             # We always append "links"
-            self.assertItemsEqual(['uuid', 'extra', 'links'], allocation)
+            self.assertCountEqual(['uuid', 'extra', 'links'], allocation)
 
     def test_get_custom_fields_invalid_fields(self):
         allocation = obj_utils.create_test_allocation(self.context,
@@ -597,8 +585,9 @@ class TestPatch(test_api_base.BaseApiTest):
         self.assertEqual(http_client.BAD_REQUEST, response.status_int)
         self.assertTrue(response.json['error_message'])
 
-    @mock.patch.object(notification_utils, '_emit_api_notification')
-    @mock.patch.object(timeutils, 'utcnow')
+    @mock.patch.object(notification_utils, '_emit_api_notification',
+                       autospec=True)
+    @mock.patch.object(timeutils, 'utcnow', autospec=True)
     def test_replace_singular(self, mock_utcnow, mock_notify):
         test_time = datetime.datetime(2000, 1, 1, 0, 0)
 
@@ -633,8 +622,9 @@ class TestPatch(test_api_base.BaseApiTest):
                                headers=self.headers)
         self.assertIsNone(result['name'])
 
-    @mock.patch.object(notification_utils, '_emit_api_notification')
-    @mock.patch.object(objects.Allocation, 'save')
+    @mock.patch.object(notification_utils, '_emit_api_notification',
+                       autospec=True)
+    @mock.patch.object(objects.Allocation, 'save', autospec=True)
     def test_update_error(self, mock_save, mock_notify):
         mock_save.side_effect = Exception()
         allocation = obj_utils.create_test_allocation(self.context)
@@ -764,7 +754,8 @@ class TestPost(test_api_base.BaseApiTest):
         ).mock
         self.mock_get_topic_for_node.return_value = 'node-topic'
 
-    @mock.patch.object(notification_utils, '_emit_api_notification')
+    @mock.patch.object(notification_utils, '_emit_api_notification',
+                       autospec=True)
     @mock.patch.object(timeutils, 'utcnow', autospec=True)
     def test_create_allocation(self, mock_utcnow, mock_notify):
         adict = apiutils.allocation_post_data()
@@ -836,8 +827,9 @@ class TestPost(test_api_base.BaseApiTest):
         self.assertFalse(mock_warn.called)
         self.assertFalse(mock_except.called)
 
-    @mock.patch.object(notification_utils, '_emit_api_notification')
-    @mock.patch.object(objects.Allocation, 'create')
+    @mock.patch.object(notification_utils, '_emit_api_notification',
+                       autospec=True)
+    @mock.patch.object(objects.Allocation, 'create', autospec=True)
     def test_create_allocation_error(self, mock_create, mock_notify):
         mock_create.side_effect = Exception()
         adict = apiutils.allocation_post_data()
@@ -1168,7 +1160,7 @@ class TestPost(test_api_base.BaseApiTest):
         self.assertTrue(response.json['error_message'])
 
 
-@mock.patch.object(rpcapi.ConductorAPI, 'destroy_allocation')
+@mock.patch.object(rpcapi.ConductorAPI, 'destroy_allocation', autospec=True)
 class TestDelete(test_api_base.BaseApiTest):
     headers = {api_base.Version.string: str(api_v1.max_version())}
 
@@ -1182,7 +1174,8 @@ class TestDelete(test_api_base.BaseApiTest):
             fixtures.MockPatchObject(rpcapi.ConductorAPI, 'get_random_topic')
         ).mock
 
-    @mock.patch.object(notification_utils, '_emit_api_notification')
+    @mock.patch.object(notification_utils, '_emit_api_notification',
+                       autospec=True)
     def test_delete_allocation_by_id(self, mock_notify, mock_destroy):
         self.delete('/allocations/%s' % self.allocation.uuid,
                     headers=self.headers)
@@ -1198,7 +1191,8 @@ class TestDelete(test_api_base.BaseApiTest):
                       node_uuid=self.node.uuid),
         ])
 
-    @mock.patch.object(notification_utils, '_emit_api_notification')
+    @mock.patch.object(notification_utils, '_emit_api_notification',
+                       autospec=True)
     def test_delete_allocation_node_locked(self, mock_notify, mock_destroy):
         self.node.reserve(self.context, 'fake', self.node.uuid)
         mock_destroy.side_effect = exception.NodeLocked(node='fake-node',
@@ -1248,7 +1242,8 @@ class TestDelete(test_api_base.BaseApiTest):
                           headers=self.headers)
         self.assertEqual(http_client.NOT_FOUND, res.status_code)
 
-    @mock.patch.object(notification_utils, '_emit_api_notification')
+    @mock.patch.object(notification_utils, '_emit_api_notification',
+                       autospec=True)
     def test_delete_allocation_by_node(self, mock_notify, mock_destroy):
         self.delete('/nodes/%s/allocation' % self.node.uuid,
                     headers=self.headers)
