@@ -282,22 +282,22 @@ class DefaultInterfaceTestCase(db_base.DbTestCase):
 
     def test_calculated_with_one(self):
         self.config(default_deploy_interface=None)
-        self.config(enabled_deploy_interfaces=['direct'])
+        self.config(enabled_deploy_interfaces=['ansible'])
         iface = driver_factory.default_interface(self.driver, 'deploy')
-        self.assertEqual('direct', iface)
+        self.assertEqual('ansible', iface)
 
     def test_calculated_with_two(self):
         self.config(default_deploy_interface=None)
-        self.config(enabled_deploy_interfaces=['iscsi', 'direct'])
+        self.config(enabled_deploy_interfaces=['ansible', 'direct'])
         iface = driver_factory.default_interface(self.driver, 'deploy')
-        self.assertEqual('iscsi', iface)
+        self.assertEqual('direct', iface)
 
     def test_calculated_with_unsupported(self):
         self.config(default_deploy_interface=None)
         # manual-management doesn't support fake deploy
-        self.config(enabled_deploy_interfaces=['fake', 'direct'])
+        self.config(enabled_deploy_interfaces=['fake', 'ansible'])
         iface = driver_factory.default_interface(self.driver, 'deploy')
-        self.assertEqual('direct', iface)
+        self.assertEqual('ansible', iface)
 
     def test_calculated_no_answer(self):
         # manual-management supports no power interfaces
@@ -333,6 +333,17 @@ class DefaultInterfaceTestCase(db_base.DbTestCase):
             driver_factory.default_interface, self.driver, 'power',
             driver_name='foo', node='bar')
 
+    @mock.patch.object(driver_factory, 'get_interface', autospec=True)
+    def test_check_exception_IncompatibleInterface(self, mock_get_interface):
+        self.config(enabled_management_interfaces=['redfish'])
+        self.config(default_management_interface=['redfish'])
+        mock_get_interface.side_effect = exception.IncompatibleInterface(
+            interface_type='management',
+            hardware_type=self.driver)
+        self.assertRaises(exception.NoValidDefaultForInterface,
+                          driver_factory.default_interface, self.driver,
+                          'management')
+
 
 class TestFakeHardware(hardware_type.AbstractHardwareType):
     @property
