@@ -89,7 +89,7 @@ class DoNodeCleanTestCase(db_base.DbTestCase):
     def test__do_node_clean_manual_network_validate_fail(self, mock_validate):
         self.__do_node_clean_validate_fail(mock_validate, clean_steps=[])
 
-    @mock.patch.object(cleaning, 'LOG', autospec=True)
+    @mock.patch.object(conductor_utils, 'LOG', autospec=True)
     @mock.patch.object(conductor_steps, 'set_node_cleaning_steps',
                        autospec=True)
     @mock.patch.object(cleaning, 'do_next_clean_step', autospec=True)
@@ -128,8 +128,7 @@ class DoNodeCleanTestCase(db_base.DbTestCase):
             mock_validate.assert_called_once_with(mock.ANY, task)
             if enable_exception:
                 mock_log.exception.assert_called_once_with(
-                    'Caching of bios settings failed on node {}. '
-                    'Continuing with node cleaning.'
+                    'Caching of bios settings failed on node {}.'
                     .format(node.uuid))
 
     def test__do_node_clean_manual_cache_bios(self):
@@ -197,6 +196,30 @@ class DoNodeCleanTestCase(db_base.DbTestCase):
         self.assertTrue(mock_validate.called)
         self.assertIn('clean_steps', node.driver_internal_info)
 
+    @mock.patch('ironic.drivers.modules.fake.FakePower.validate',
+                autospec=True)
+    def test__do_node_clean_automated_enabled_individual_disabled(
+            self, mock_validate):
+        self.config(automated_clean=True, group='conductor')
+
+        node = obj_utils.create_test_node(
+            self.context, driver='fake-hardware',
+            provision_state=states.CLEANING,
+            target_provision_state=states.AVAILABLE,
+            last_error=None, automated_clean=False)
+        with task_manager.acquire(
+                self.context, node.uuid, shared=False) as task:
+            cleaning.do_node_clean(task)
+        node.refresh()
+
+        # Assert that the node was moved to available without cleaning
+        self.assertFalse(mock_validate.called)
+        self.assertEqual(states.AVAILABLE, node.provision_state)
+        self.assertEqual(states.NOSTATE, node.target_provision_state)
+        self.assertEqual({}, node.clean_step)
+        self.assertNotIn('clean_steps', node.driver_internal_info)
+        self.assertNotIn('clean_step_index', node.driver_internal_info)
+
     @mock.patch('ironic.drivers.modules.fake.FakePower.validate',
                 autospec=True)
     def test__do_node_clean_automated_disabled_individual_disabled(
@@ -1037,6 +1060,35 @@ class DoNodeCleanTestCase(db_base.DbTestCase):
     def test__do_next_clean_step_manual_bad_step_return_value(self):
         self._do_next_clean_step_bad_step_return_value(manual=True)
 
+    @mock.patch.object(cleaning, 'do_next_clean_step', autospec=True)
+    def _continue_node_clean(self, mock_next_step, skip=True):
+        # test that skipping current step mechanism works
+        driver_info = {'clean_steps': self.clean_steps,
+                       'clean_step_index': 0,
+                       'cleaning_polling': 'value'}
+        if not skip:
+            driver_info['skip_current_clean_step'] = skip
+        node = obj_utils.create_test_node(
+            self.context, driver='fake-hardware',
+            provision_state=states.CLEANING,
+            target_provision_state=states.MANAGEABLE,
+            driver_internal_info=driver_info,
+            clean_step=self.clean_steps[0])
+        with task_manager.acquire(self.context, node.uuid) as task:
+            cleaning.continue_node_clean(task)
+            expected_step_index = 1 if skip else 0
+            self.assertNotIn(
+                'skip_current_clean_step', task.node.driver_internal_info)
+            self.assertNotIn(
+                'cleaning_polling', task.node.driver_internal_info)
+            mock_next_step.assert_called_once_with(task, expected_step_index)
+
+    def test_continue_node_clean(self):
+        self._continue_node_clean(skip=True)
+
+    def test_continue_node_clean_no_skip_step(self):
+        self._continue_node_clean(skip=False)
+
 
 class DoNodeCleanAbortTestCase(db_base.DbTestCase):
     @mock.patch.object(fake.FakeDeploy, 'tear_down_cleaning', autospec=True)
