@@ -83,7 +83,7 @@ class IloValidateParametersTestCase(BaseIloTest):
         self.assertEqual(INFO_DICT['ilo_password'], info['ilo_password'])
         self.assertEqual(60, info['client_timeout'])
         self.assertEqual(443, info['client_port'])
-        self.assertEqual('/home/user/cafile.pem', info['ca_file'])
+        self.assertEqual('/home/user/cafile.pem', info['verify_ca'])
         self.assertEqual('user', info['snmp_auth_user'])
         self.assertEqual('1234', info['snmp_auth_prot_password'])
         self.assertEqual('4321', info['snmp_auth_priv_password'])
@@ -99,6 +99,81 @@ class IloValidateParametersTestCase(BaseIloTest):
         self.assertEqual(60, info['client_timeout'])
         self.assertEqual(443, info['client_port'])
 
+    @mock.patch.object(os.path, 'isdir', autospec=True)
+    def test_parse_driver_info_path_verify_ca_dir(self, mock_isdir):
+        mock_isdir.return_value = True
+        fake_path = '/path/to/a/valid/CA'
+        self.node.driver_info['ilo_verify_ca'] = fake_path
+        info = ilo_common.parse_driver_info(self.node)
+        self.assertEqual(INFO_DICT['ilo_address'], info['ilo_address'])
+        self.assertEqual(INFO_DICT['ilo_username'], info['ilo_username'])
+        self.assertEqual(INFO_DICT['ilo_password'], info['ilo_password'])
+        self.assertEqual(60, info['client_timeout'])
+        self.assertEqual(443, info['client_port'])
+        self.assertEqual(fake_path, info['verify_ca'])
+        mock_isdir.assert_called_once_with(fake_path)
+
+    @mock.patch.object(os.path, 'isfile', autospec=True)
+    def test_parse_driver_info_path_verify_ca_file(self, mock_isfile):
+        mock_isfile.return_value = True
+        fake_path = '/path/to/a/valid/CA.pem'
+        self.node.driver_info['ilo_verify_ca'] = fake_path
+        info = ilo_common.parse_driver_info(self.node)
+        self.assertEqual(INFO_DICT['ilo_address'], info['ilo_address'])
+        self.assertEqual(INFO_DICT['ilo_username'], info['ilo_username'])
+        self.assertEqual(INFO_DICT['ilo_password'], info['ilo_password'])
+        self.assertEqual(60, info['client_timeout'])
+        self.assertEqual(443, info['client_port'])
+        self.assertEqual(fake_path, info['verify_ca'])
+        mock_isfile.assert_called_once_with(fake_path)
+
+    def test_parse_driver_info_verify_ca_default_value(self):
+        info = ilo_common.parse_driver_info(self.node)
+        self.assertEqual(INFO_DICT['ilo_address'], info['ilo_address'])
+        self.assertEqual(INFO_DICT['ilo_username'], info['ilo_username'])
+        self.assertEqual(INFO_DICT['ilo_password'], info['ilo_password'])
+        self.assertEqual(60, info['client_timeout'])
+        self.assertEqual(443, info['client_port'])
+        self.assertEqual(True, info['verify_ca'])
+
+    def test_parse_driver_info_verify_ca_string_false(self):
+        self.config(verify_ca="False", group='ilo')
+        info = ilo_common.parse_driver_info(self.node)
+        self.assertEqual(INFO_DICT['ilo_address'], info['ilo_address'])
+        self.assertEqual(INFO_DICT['ilo_username'], info['ilo_username'])
+        self.assertEqual(INFO_DICT['ilo_password'], info['ilo_password'])
+        self.assertEqual(60, info['client_timeout'])
+        self.assertEqual(443, info['client_port'])
+        self.assertEqual(False, info['verify_ca'])
+
+    def test_parse_driver_info_verify_ca_boolean_true(self):
+        self.config(verify_ca=True, group='ilo')
+        info = ilo_common.parse_driver_info(self.node)
+        self.assertEqual(INFO_DICT['ilo_address'], info['ilo_address'])
+        self.assertEqual(INFO_DICT['ilo_username'], info['ilo_username'])
+        self.assertEqual(INFO_DICT['ilo_password'], info['ilo_password'])
+        self.assertEqual(60, info['client_timeout'])
+        self.assertEqual(443, info['client_port'])
+        self.assertEqual(True, info['verify_ca'])
+
+    def test_parse_driver_info_verify_ca_boolean_false(self):
+        self.config(verify_ca=False, group='ilo')
+        info = ilo_common.parse_driver_info(self.node)
+        self.assertEqual(INFO_DICT['ilo_address'], info['ilo_address'])
+        self.assertEqual(INFO_DICT['ilo_username'], info['ilo_username'])
+        self.assertEqual(INFO_DICT['ilo_password'], info['ilo_password'])
+        self.assertEqual(60, info['client_timeout'])
+        self.assertEqual(443, info['client_port'])
+        self.assertEqual(False, info['verify_ca'])
+
+    def test_parse_driver_info_invalid_value_verify_ca(self):
+        # Integers are not supported
+        self.node.driver_info['ilo_verify_ca'] = 123456
+        self.assertRaisesRegex(exception.InvalidParameterValue,
+                               'Invalid value type',
+                               ilo_common._parse_optional_driver_info,
+                               self.node)
+
     @mock.patch.object(os.path, 'isfile', return_value=True, autospec=True)
     def test_parse_driver_info_snmp_true_no_auth_priv_protocols(self,
                                                                 isFile_mock):
@@ -113,7 +188,7 @@ class IloValidateParametersTestCase(BaseIloTest):
         self.assertEqual(INFO_DICT['ilo_password'], info['ilo_password'])
         self.assertEqual(60, info['client_timeout'])
         self.assertEqual(443, info['client_port'])
-        self.assertEqual('/home/user/cafile.pem', info['ca_file'])
+        self.assertEqual('/home/user/cafile.pem', info['verify_ca'])
         self.assertEqual('user', info['snmp_auth_user'])
         self.assertEqual('1234', info['snmp_auth_prot_password'])
         self.assertEqual('4321', info['snmp_auth_priv_password'])
@@ -230,7 +305,7 @@ class IloCommonMethodsTestCase(BaseIloTest):
     def _test_get_ilo_object(self, ilo_client_mock, isFile_mock, ca_file=None):
         self.info['client_timeout'] = 600
         self.info['client_port'] = 4433
-        self.info['ca_file'] = ca_file
+        self.info['ilo_verify_ca'] = ca_file
         self.node.driver_info = self.info
         ilo_client_mock.return_value = 'ilo_object'
         returned_ilo_object = ilo_common.get_ilo_object(self.node)
@@ -240,7 +315,7 @@ class IloCommonMethodsTestCase(BaseIloTest):
             self.info['ilo_password'],
             self.info['client_timeout'],
             self.info['client_port'],
-            cacert=self.info['ca_file'],
+            cacert=self.info['ilo_verify_ca'],
             snmp_credentials=None)
         self.assertEqual('ilo_object', returned_ilo_object)
 
@@ -256,7 +331,7 @@ class IloCommonMethodsTestCase(BaseIloTest):
                 'snmp_inspection': True}
         d_info = {'client_timeout': 600,
                   'client_port': 4433,
-                  'ca_file': 'ca_file',
+                  'verify_ca': 'True',
                   'snmp_auth_user': 'user',
                   'snmp_auth_prot_password': '1234',
                   'snmp_auth_priv_password': '4321',
@@ -272,15 +347,15 @@ class IloCommonMethodsTestCase(BaseIloTest):
             self.info['ilo_password'],
             self.info['client_timeout'],
             self.info['client_port'],
-            cacert=self.info['ca_file'],
+            cacert=self.info['verify_ca'],
             snmp_credentials=info)
         self.assertEqual('ilo_object', returned_ilo_object)
 
     def test_get_ilo_object_cafile(self):
         self._test_get_ilo_object(ca_file='/home/user/ilo.pem')
 
-    def test_get_ilo_object_no_cafile(self):
-        self._test_get_ilo_object()
+    def test_get_ilo_object_cafile_boolean(self):
+        self._test_get_ilo_object(ca_file=True)
 
     def test_update_ipmi_properties(self):
         with task_manager.acquire(self.context, self.node.uuid,
@@ -465,7 +540,7 @@ class IloCommonMethodsTestCase(BaseIloTest):
                                                    set_boot_mode_mock):
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=False) as task:
-            task.node.instance_info['deploy_boot_mode'] = 'bios'
+            task.node.driver_internal_info['deploy_boot_mode'] = 'bios'
             ilo_common.update_boot_mode(task)
             set_boot_mode_mock.assert_called_once_with(task.node, 'bios')
 
@@ -488,8 +563,8 @@ class IloCommonMethodsTestCase(BaseIloTest):
                                   shared=False) as task:
             ilo_common.update_boot_mode(task)
             set_boot_mode_mock.assert_called_once_with(task.node, 'bios')
-            self.assertEqual('bios',
-                             task.node.instance_info['deploy_boot_mode'])
+            self.assertEqual(
+                'bios', task.node.driver_internal_info['deploy_boot_mode'])
 
     @mock.patch.object(ilo_common, 'get_ilo_object', spec_set=True,
                        autospec=True)
@@ -503,8 +578,8 @@ class IloCommonMethodsTestCase(BaseIloTest):
             ilo_common.update_boot_mode(task)
             get_ilo_object_mock.assert_called_once_with(task.node)
             ilo_mock_obj.get_pending_boot_mode.assert_called_once_with()
-            self.assertEqual('bios',
-                             task.node.instance_info['deploy_boot_mode'])
+            self.assertEqual(
+                'bios', task.node.driver_internal_info['deploy_boot_mode'])
 
     @mock.patch.object(ilo_common, 'get_ilo_object', spec_set=True,
                        autospec=True)
@@ -520,8 +595,8 @@ class IloCommonMethodsTestCase(BaseIloTest):
             get_ilo_object_mock.assert_called_once_with(task.node)
             ilo_mock_obj.get_pending_boot_mode.assert_called_once_with()
             set_pending_boot_mode_mock.assert_called_once_with('UEFI')
-            self.assertEqual('uefi',
-                             task.node.instance_info['deploy_boot_mode'])
+            self.assertEqual(
+                'uefi', task.node.driver_internal_info['deploy_boot_mode'])
 
     @mock.patch.object(ilo_common, 'get_ilo_object', spec_set=True,
                        autospec=True)
@@ -553,8 +628,8 @@ class IloCommonMethodsTestCase(BaseIloTest):
             ilo_common.update_boot_mode(task)
             get_ilo_object_mock.assert_called_once_with(task.node)
             ilo_mock_obj.get_pending_boot_mode.assert_called_once_with()
-            self.assertEqual('bios',
-                             task.node.instance_info['deploy_boot_mode'])
+            self.assertEqual(
+                'bios', task.node.driver_internal_info['deploy_boot_mode'])
 
     @mock.patch.object(ilo_common, 'set_boot_mode', spec_set=True,
                        autospec=True)
@@ -600,7 +675,6 @@ class IloCommonMethodsTestCase(BaseIloTest):
         swift_obj_mock = swift_api_mock.return_value
         boot_iso = 'swift:object-name'
         swift_obj_mock.get_temp_url.return_value = 'image_url'
-        CONF.keystone_authtoken.auth_uri = 'http://authurl'
         CONF.ilo.swift_ilo_container = 'ilo_cont'
         CONF.ilo.swift_object_expiry_timeout = 1
         with task_manager.acquire(self.context, self.node.uuid,
@@ -1005,6 +1079,21 @@ class IloCommonMethodsTestCase(BaseIloTest):
             func_set_boot_device.assert_called_once_with(task,
                                                          boot_devices.CDROM)
 
+    @mock.patch.object(manager_utils, 'node_set_boot_device', spec_set=True,
+                       autospec=True)
+    @mock.patch.object(ilo_common, 'setup_vmedia_for_boot', spec_set=True,
+                       autospec=True)
+    def test_setup_vmedia_without_params(self,
+                                         func_setup_vmedia_for_boot,
+                                         func_set_boot_device):
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            iso = '733d1c44-a2ea-414b-aca7-69decf20d810'
+            ilo_common.setup_vmedia(task, iso)
+            func_setup_vmedia_for_boot.assert_called_once_with(task, iso, None)
+            func_set_boot_device.assert_called_once_with(task,
+                                                         boot_devices.CDROM)
+
     @mock.patch.object(deploy_utils, 'is_secure_boot_requested', spec_set=True,
                        autospec=True)
     @mock.patch.object(ilo_common, 'set_secure_boot_mode', spec_set=True,
@@ -1131,3 +1220,79 @@ class IloCommonMethodsTestCase(BaseIloTest):
                               ilo_common.get_server_post_state,
                               task.node)
         ilo_mock_object.get_host_post_state.assert_called_once_with()
+
+    @mock.patch.object(ilo_common, 'get_ilo_object', spec_set=True,
+                       autospec=True)
+    def test_setup_uefi_https_scheme_http(self, get_ilo_object_mock):
+        ilo_mock_object = get_ilo_object_mock.return_value
+        iso = "http://1.1.1.1/image.iso"
+
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            self.assertRaises(exception.IloOperationNotSupported,
+                              ilo_common.setup_uefi_https,
+                              task, iso, True)
+
+        ilo_mock_object.set_http_boot_url.assert_not_called()
+        ilo_mock_object.set_one_time_boot.assert_not_called()
+        ilo_mock_object.update_persistent_boot.assert_not_called()
+
+    @mock.patch.object(ilo_common, 'get_ilo_object', spec_set=True,
+                       autospec=True)
+    def _test_setup_uefi_https(self, get_ilo_object_mock, persistent):
+
+        ilo_mock_object = get_ilo_object_mock.return_value
+
+        iso = "https://1.1.1.1/image.iso"
+
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            ilo_common.setup_uefi_https(task, iso, persistent=persistent)
+
+        ilo_mock_object.set_http_boot_url.assert_called_once_with(iso)
+        if persistent:
+            ilo_mock_object.set_one_time_boot.assert_not_called()
+            ilo_mock_object.update_persistent_boot.assert_called_once_with(
+                ['UEFIHTTP'])
+        else:
+            ilo_mock_object.set_one_time_boot.assert_called_once_with(
+                'UEFIHTTP')
+            ilo_mock_object.update_persistent_boot.assert_not_called()
+
+    def test_setup_uefi_https_persistent_true(self):
+        self._test_setup_uefi_https(persistent=True)
+
+    def test_setup_uefi_https_persistent_false(self):
+        self._test_setup_uefi_https(persistent=False)
+
+    @mock.patch.object(ilo_common, 'get_ilo_object', spec_set=True,
+                       autospec=True)
+    def test_setup_uefi_https_raises_not_supported(self, get_ilo_object_mock):
+        ilo_mock_object = get_ilo_object_mock.return_value
+
+        exc = ilo_error.IloCommandNotSupportedInBiosError('error')
+        ilo_mock_object.set_http_boot_url.side_effect = exc
+
+        iso = "https://1.1.1.1/image.iso"
+
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            self.assertRaises(exception.IloOperationNotSupported,
+                              ilo_common.setup_uefi_https,
+                              task, iso, True)
+
+    @mock.patch.object(ilo_common, 'get_ilo_object', spec_set=True,
+                       autospec=True)
+    def test_setup_uefi_https_raises_ilo_error(self, get_ilo_object_mock):
+        ilo_mock_object = get_ilo_object_mock.return_value
+
+        exc = ilo_error.IloError('error')
+        ilo_mock_object.set_http_boot_url.side_effect = exc
+
+        iso = "https://1.1.1.1/image.iso"
+
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            self.assertRaises(exception.IloOperationError,
+                              ilo_common.setup_uefi_https,
+                              task, iso, True)
