@@ -381,11 +381,13 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
     @mock.patch.object(redfish_boot.manager_utils, 'node_power_action',
                        autospec=True)
     @mock.patch.object(redfish_boot, 'boot_mode_utils', autospec=True)
+    @mock.patch.object(redfish_utils, 'get_system', autospec=True)
     def test_prepare_ramdisk_with_params(
-            self, mock_boot_mode_utils, mock_node_power_action,
+            self, mock_system, mock_boot_mode_utils, mock_node_power_action,
             mock__parse_driver_info, mock__insert_vmedia, mock__eject_vmedia,
             mock_prepare_deploy_iso, mock_node_set_boot_device):
 
+        managers = mock_system.return_value.managers
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=False) as task:
             task.node.provision_state = states.DEPLOYING
@@ -399,10 +401,10 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
                 task, states.POWER_OFF)
 
             mock__eject_vmedia.assert_called_once_with(
-                task, sushy.VIRTUAL_MEDIA_CD)
+                task, managers, sushy.VIRTUAL_MEDIA_CD)
 
             mock__insert_vmedia.assert_called_once_with(
-                task, 'image-url', sushy.VIRTUAL_MEDIA_CD)
+                task, managers, 'image-url', sushy.VIRTUAL_MEDIA_CD)
 
             expected_params = {
                 'ipa-agent-token': mock.ANY,
@@ -426,11 +428,13 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
     @mock.patch.object(redfish_boot.manager_utils, 'node_power_action',
                        autospec=True)
     @mock.patch.object(redfish_boot, 'boot_mode_utils', autospec=True)
+    @mock.patch.object(redfish_utils, 'get_system', autospec=True)
     def test_prepare_ramdisk_no_debug(
-            self, mock_boot_mode_utils, mock_node_power_action,
+            self, mock_system, mock_boot_mode_utils, mock_node_power_action,
             mock__parse_driver_info, mock__insert_vmedia, mock__eject_vmedia,
             mock_prepare_deploy_iso, mock_node_set_boot_device):
         self.config(debug=False)
+        managers = mock_system.return_value.managers
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
             task.node.provision_state = states.DEPLOYING
@@ -444,10 +448,10 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
                 task, states.POWER_OFF)
 
             mock__eject_vmedia.assert_called_once_with(
-                task, sushy.VIRTUAL_MEDIA_CD)
+                task, managers, sushy.VIRTUAL_MEDIA_CD)
 
             mock__insert_vmedia.assert_called_once_with(
-                task, 'image-url', sushy.VIRTUAL_MEDIA_CD)
+                task, managers, 'image-url', sushy.VIRTUAL_MEDIA_CD)
 
             expected_params = {
                 'ipa-agent-token': mock.ANY,
@@ -472,12 +476,14 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
     @mock.patch.object(redfish_boot.manager_utils, 'node_power_action',
                        autospec=True)
     @mock.patch.object(redfish_boot, 'boot_mode_utils', autospec=True)
+    @mock.patch.object(redfish_utils, 'get_system', autospec=True)
     def test_prepare_ramdisk_with_floppy(
-            self, mock_boot_mode_utils, mock_node_power_action,
+            self, mock_system, mock_boot_mode_utils, mock_node_power_action,
             mock__parse_driver_info, mock__insert_vmedia, mock__eject_vmedia,
             mock__has_vmedia_device, mock_prepare_deploy_iso,
             mock_prepare_floppy_image, mock_node_set_boot_device):
 
+        managers = mock_system.return_value.managers
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=False) as task:
             task.node.provision_state = states.DEPLOYING
@@ -498,19 +504,20 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
                 task, states.POWER_OFF)
 
             mock__has_vmedia_device.assert_called_once_with(
-                task, sushy.VIRTUAL_MEDIA_FLOPPY)
+                managers, sushy.VIRTUAL_MEDIA_FLOPPY)
 
             eject_calls = [
-                mock.call(task, sushy.VIRTUAL_MEDIA_FLOPPY),
-                mock.call(task, sushy.VIRTUAL_MEDIA_CD)
+                mock.call(task, managers, dev)
+                for dev in (sushy.VIRTUAL_MEDIA_FLOPPY,
+                            sushy.VIRTUAL_MEDIA_CD)
             ]
 
             mock__eject_vmedia.assert_has_calls(eject_calls)
 
             insert_calls = [
-                mock.call(task, 'floppy-image-url',
+                mock.call(task, managers, 'floppy-image-url',
                           sushy.VIRTUAL_MEDIA_FLOPPY),
-                mock.call(task, 'cd-image-url',
+                mock.call(task, managers, 'cd-image-url',
                           sushy.VIRTUAL_MEDIA_CD),
             ]
 
@@ -535,11 +542,13 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
     @mock.patch.object(image_utils, 'cleanup_iso_image', autospec=True)
     @mock.patch.object(image_utils, 'cleanup_floppy_image', autospec=True)
     @mock.patch.object(redfish_boot, '_parse_driver_info', autospec=True)
+    @mock.patch.object(redfish_utils, 'get_system', autospec=True)
     def test_clean_up_ramdisk(
-            self, mock__parse_driver_info, mock_cleanup_floppy_image,
-            mock_cleanup_iso_image, mock__eject_vmedia,
-            mock__has_vmedia_device):
+            self, mock_system, mock__parse_driver_info,
+            mock_cleanup_floppy_image, mock_cleanup_iso_image,
+            mock__eject_vmedia, mock__has_vmedia_device):
 
+        managers = mock_system.return_value.managers
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
             task.node.provision_state = states.DEPLOYING
@@ -554,17 +563,17 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
             mock_cleanup_floppy_image.assert_called_once_with(task)
 
             mock__has_vmedia_device.assert_called_once_with(
-                task, sushy.VIRTUAL_MEDIA_FLOPPY)
+                managers, sushy.VIRTUAL_MEDIA_FLOPPY)
 
             eject_calls = [
-                mock.call(task, sushy.VIRTUAL_MEDIA_CD),
-                mock.call(task, sushy.VIRTUAL_MEDIA_FLOPPY)
+                mock.call(task, managers, sushy.VIRTUAL_MEDIA_CD),
+                mock.call(task, managers, sushy.VIRTUAL_MEDIA_FLOPPY)
             ]
 
             mock__eject_vmedia.assert_has_calls(eject_calls)
 
     @mock.patch.object(redfish_boot.RedfishVirtualMediaBoot,
-                       'clean_up_instance', autospec=True)
+                       '_eject_all', autospec=True)
     @mock.patch.object(image_utils, 'prepare_boot_iso', autospec=True)
     @mock.patch.object(redfish_boot, '_eject_vmedia', autospec=True)
     @mock.patch.object(redfish_boot, '_insert_vmedia', autospec=True)
@@ -572,11 +581,13 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
     @mock.patch.object(redfish_boot, 'manager_utils', autospec=True)
     @mock.patch.object(redfish_boot, 'deploy_utils', autospec=True)
     @mock.patch.object(redfish_boot, 'boot_mode_utils', autospec=True)
+    @mock.patch.object(redfish_utils, 'get_system', autospec=True)
     def test_prepare_instance_normal_boot(
-            self, mock_boot_mode_utils, mock_deploy_utils, mock_manager_utils,
-            mock__parse_deploy_info, mock__insert_vmedia, mock__eject_vmedia,
-            mock_prepare_boot_iso, mock_clean_up_instance):
+            self, mock_system, mock_boot_mode_utils, mock_deploy_utils,
+            mock_manager_utils, mock__parse_deploy_info, mock__insert_vmedia,
+            mock__eject_vmedia, mock_prepare_boot_iso, mock_clean_up_instance):
 
+        managers = mock_system.return_value.managers
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
             task.node.provision_state = states.DEPLOYING
@@ -605,18 +616,21 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
                 task, d_info, **expected_params)
 
             mock__eject_vmedia.assert_called_once_with(
-                task, sushy.VIRTUAL_MEDIA_CD)
+                task, managers, sushy.VIRTUAL_MEDIA_CD)
 
             mock__insert_vmedia.assert_called_once_with(
-                task, 'image-url', sushy.VIRTUAL_MEDIA_CD)
+                task, managers, 'image-url', sushy.VIRTUAL_MEDIA_CD)
 
             mock_manager_utils.node_set_boot_device.assert_called_once_with(
                 task, boot_devices.CDROM, persistent=True)
 
             mock_boot_mode_utils.sync_boot_mode.assert_called_once_with(task)
+            csb = mock_boot_mode_utils.configure_secure_boot_if_needed
+            csb.assert_called_once_with(task)
 
     @mock.patch.object(redfish_boot.RedfishVirtualMediaBoot,
-                       'clean_up_instance', autospec=True)
+                       '_eject_all', autospec=True)
+    @mock.patch.object(image_utils, 'prepare_configdrive_image', autospec=True)
     @mock.patch.object(image_utils, 'prepare_boot_iso', autospec=True)
     @mock.patch.object(redfish_boot, '_eject_vmedia', autospec=True)
     @mock.patch.object(redfish_boot, '_insert_vmedia', autospec=True)
@@ -624,16 +638,21 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
     @mock.patch.object(redfish_boot, 'manager_utils', autospec=True)
     @mock.patch.object(redfish_boot, 'deploy_utils', autospec=True)
     @mock.patch.object(redfish_boot, 'boot_mode_utils', autospec=True)
+    @mock.patch.object(redfish_utils, 'get_system', autospec=True)
     def test_prepare_instance_ramdisk_boot(
-            self, mock_boot_mode_utils, mock_deploy_utils, mock_manager_utils,
-            mock__parse_deploy_info, mock__insert_vmedia, mock__eject_vmedia,
-            mock_prepare_boot_iso, mock_clean_up_instance):
+            self, mock_system, mock_boot_mode_utils, mock_deploy_utils,
+            mock_manager_utils, mock__parse_deploy_info, mock__insert_vmedia,
+            mock__eject_vmedia, mock_prepare_boot_iso, mock_prepare_disk,
+            mock_clean_up_instance):
 
+        configdrive = 'Y29udGVudA=='
+        managers = mock_system.return_value.managers
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
             task.node.provision_state = states.DEPLOYING
             task.node.driver_internal_info[
                 'root_uuid_or_disk_id'] = self.node.uuid
+            task.node.instance_info['configdrive'] = configdrive
 
             mock_deploy_utils.get_boot_option.return_value = 'ramdisk'
 
@@ -645,18 +664,26 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
             mock__parse_deploy_info.return_value = d_info
 
             mock_prepare_boot_iso.return_value = 'image-url'
+            mock_prepare_disk.return_value = 'cd-url'
 
             task.driver.boot.prepare_instance(task)
 
             mock_clean_up_instance.assert_called_once_with(mock.ANY, task)
 
             mock_prepare_boot_iso.assert_called_once_with(task, d_info)
+            mock_prepare_disk.assert_called_once_with(task, configdrive)
 
-            mock__eject_vmedia.assert_called_once_with(
-                task, sushy.VIRTUAL_MEDIA_CD)
+            mock__eject_vmedia.assert_has_calls([
+                mock.call(task, managers, sushy.VIRTUAL_MEDIA_CD),
+                mock.call(task, managers, sushy.VIRTUAL_MEDIA_USBSTICK),
+            ])
 
-            mock__insert_vmedia.assert_called_once_with(
-                task, 'image-url', sushy.VIRTUAL_MEDIA_CD)
+            mock__insert_vmedia.assert_has_calls([
+                mock.call(task, managers,
+                          'image-url', sushy.VIRTUAL_MEDIA_CD),
+                mock.call(task, managers,
+                          'cd-url', sushy.VIRTUAL_MEDIA_USBSTICK),
+            ])
 
             mock_manager_utils.node_set_boot_device.assert_called_once_with(
                 task, boot_devices.CDROM, persistent=True)
@@ -664,7 +691,7 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
             mock_boot_mode_utils.sync_boot_mode.assert_called_once_with(task)
 
     @mock.patch.object(redfish_boot.RedfishVirtualMediaBoot,
-                       'clean_up_instance', autospec=True)
+                       '_eject_all', autospec=True)
     @mock.patch.object(image_utils, 'prepare_boot_iso', autospec=True)
     @mock.patch.object(redfish_boot, '_eject_vmedia', autospec=True)
     @mock.patch.object(redfish_boot, '_insert_vmedia', autospec=True)
@@ -672,16 +699,19 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
     @mock.patch.object(redfish_boot, 'manager_utils', autospec=True)
     @mock.patch.object(redfish_boot, 'deploy_utils', autospec=True)
     @mock.patch.object(redfish_boot, 'boot_mode_utils', autospec=True)
+    @mock.patch.object(redfish_utils, 'get_system', autospec=True)
     def test_prepare_instance_ramdisk_boot_iso(
-            self, mock_boot_mode_utils, mock_deploy_utils, mock_manager_utils,
-            mock__parse_deploy_info, mock__insert_vmedia, mock__eject_vmedia,
-            mock_prepare_boot_iso, mock_clean_up_instance):
+            self, mock_system, mock_boot_mode_utils, mock_deploy_utils,
+            mock_manager_utils, mock__parse_deploy_info, mock__insert_vmedia,
+            mock__eject_vmedia, mock_prepare_boot_iso, mock_clean_up_instance):
 
+        managers = mock_system.return_value.managers
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
             task.node.provision_state = states.DEPLOYING
             task.node.driver_internal_info[
                 'root_uuid_or_disk_id'] = self.node.uuid
+            task.node.instance_info['configdrive'] = None
 
             mock_deploy_utils.get_boot_option.return_value = 'ramdisk'
 
@@ -699,10 +729,10 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
             mock_prepare_boot_iso.assert_called_once_with(task, d_info)
 
             mock__eject_vmedia.assert_called_once_with(
-                task, sushy.VIRTUAL_MEDIA_CD)
+                task, managers, sushy.VIRTUAL_MEDIA_CD)
 
             mock__insert_vmedia.assert_called_once_with(
-                task, 'image-url', sushy.VIRTUAL_MEDIA_CD)
+                task, managers, 'image-url', sushy.VIRTUAL_MEDIA_CD)
 
             mock_manager_utils.node_set_boot_device.assert_called_once_with(
                 task, boot_devices.CDROM, persistent=True)
@@ -710,7 +740,7 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
             mock_boot_mode_utils.sync_boot_mode.assert_called_once_with(task)
 
     @mock.patch.object(redfish_boot.RedfishVirtualMediaBoot,
-                       'clean_up_instance', autospec=True)
+                       '_eject_all', autospec=True)
     @mock.patch.object(image_utils, 'prepare_boot_iso', autospec=True)
     @mock.patch.object(redfish_boot, '_eject_vmedia', autospec=True)
     @mock.patch.object(redfish_boot, '_insert_vmedia', autospec=True)
@@ -718,16 +748,19 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
     @mock.patch.object(redfish_boot, 'manager_utils', autospec=True)
     @mock.patch.object(redfish_boot, 'deploy_utils', autospec=True)
     @mock.patch.object(redfish_boot, 'boot_mode_utils', autospec=True)
+    @mock.patch.object(redfish_utils, 'get_system', autospec=True)
     def test_prepare_instance_ramdisk_boot_iso_boot(
-            self, mock_boot_mode_utils, mock_deploy_utils, mock_manager_utils,
-            mock__parse_deploy_info, mock__insert_vmedia, mock__eject_vmedia,
-            mock_prepare_boot_iso, mock_clean_up_instance):
+            self, mock_system, mock_boot_mode_utils, mock_deploy_utils,
+            mock_manager_utils, mock__parse_deploy_info, mock__insert_vmedia,
+            mock__eject_vmedia, mock_prepare_boot_iso, mock_clean_up_instance):
 
+        managers = mock_system.return_value.managers
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
             task.node.provision_state = states.DEPLOYING
             i_info = task.node.instance_info
             i_info['boot_iso'] = "super-magic"
+            del i_info['configdrive']
             task.node.instance_info = i_info
             mock_deploy_utils.get_boot_option.return_value = 'ramdisk'
             mock__parse_deploy_info.return_value = {}
@@ -739,23 +772,27 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
             mock_prepare_boot_iso.assert_called_once_with(task, {})
 
             mock__eject_vmedia.assert_called_once_with(
-                task, sushy.VIRTUAL_MEDIA_CD)
+                task, managers, sushy.VIRTUAL_MEDIA_CD)
 
             mock__insert_vmedia.assert_called_once_with(
-                task, 'image-url', sushy.VIRTUAL_MEDIA_CD)
+                task, managers, 'image-url', sushy.VIRTUAL_MEDIA_CD)
 
             mock_manager_utils.node_set_boot_device.assert_called_once_with(
                 task, boot_devices.CDROM, persistent=True)
 
             mock_boot_mode_utils.sync_boot_mode.assert_called_once_with(task)
 
+    @mock.patch.object(boot_mode_utils, 'configure_secure_boot_if_needed',
+                       autospec=True)
     @mock.patch.object(boot_mode_utils, 'sync_boot_mode', autospec=True)
     @mock.patch.object(redfish_boot, '_eject_vmedia', autospec=True)
     @mock.patch.object(image_utils, 'cleanup_iso_image', autospec=True)
     @mock.patch.object(redfish_boot, 'manager_utils', autospec=True)
+    @mock.patch.object(redfish_utils, 'get_system', autospec=True)
     def _test_prepare_instance_local_boot(
-            self, mock_manager_utils,
-            mock_cleanup_iso_image, mock__eject_vmedia, mock_sync_boot_mode):
+            self, mock_system, mock_manager_utils,
+            mock_cleanup_iso_image, mock__eject_vmedia, mock_sync_boot_mode,
+            mock_secure_boot):
 
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
@@ -769,8 +806,10 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
                 task, boot_devices.DISK, persistent=True)
             mock_cleanup_iso_image.assert_called_once_with(task)
             mock__eject_vmedia.assert_called_once_with(
-                task, sushy.VIRTUAL_MEDIA_CD)
+                task, mock_system.return_value.managers,
+                sushy.VIRTUAL_MEDIA_CD)
             mock_sync_boot_mode.assert_called_once_with(task)
+            mock_secure_boot.assert_called_once_with(task)
 
     def test_prepare_instance_local_whole_disk_image(self):
         self.node.driver_internal_info = {'is_whole_disk_image': True}
@@ -784,22 +823,27 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
         self.node.save()
         self._test_prepare_instance_local_boot()
 
+    @mock.patch.object(boot_mode_utils, 'deconfigure_secure_boot_if_needed',
+                       autospec=True)
     @mock.patch.object(redfish_boot, '_eject_vmedia', autospec=True)
     @mock.patch.object(image_utils, 'cleanup_iso_image', autospec=True)
-    def _test_clean_up_instance(self, mock_cleanup_iso_image,
-                                mock__eject_vmedia):
-
+    @mock.patch.object(redfish_utils, 'get_system', autospec=True)
+    def _test_clean_up_instance(self, mock_system, mock_cleanup_iso_image,
+                                mock__eject_vmedia, mock_secure_boot):
+        managers = mock_system.return_value.managers
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
 
             task.driver.boot.clean_up_instance(task)
 
             mock_cleanup_iso_image.assert_called_once_with(task)
-            eject_calls = [mock.call(task, sushy.VIRTUAL_MEDIA_CD)]
+            eject_calls = [mock.call(task, managers, sushy.VIRTUAL_MEDIA_CD)]
             if task.node.driver_info.get('config_via_floppy'):
-                eject_calls.append(mock.call(task, sushy.VIRTUAL_MEDIA_FLOPPY))
+                eject_calls.append(mock.call(task, managers,
+                                             sushy.VIRTUAL_MEDIA_FLOPPY))
 
             mock__eject_vmedia.assert_has_calls(eject_calls)
+            mock_secure_boot.assert_called_once_with(task)
 
     def test_clean_up_instance_only_cdrom(self):
         self._test_clean_up_instance()
@@ -811,8 +855,39 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
         self.node.save()
         self._test_clean_up_instance()
 
-    @mock.patch.object(redfish_boot, 'redfish_utils', autospec=True)
-    def test__insert_vmedia_anew(self, mock_redfish_utils):
+    @mock.patch.object(boot_mode_utils, 'deconfigure_secure_boot_if_needed',
+                       autospec=True)
+    @mock.patch.object(deploy_utils, 'get_boot_option', autospec=True)
+    @mock.patch.object(redfish_boot, '_eject_vmedia', autospec=True)
+    @mock.patch.object(image_utils, 'cleanup_disk_image', autospec=True)
+    @mock.patch.object(image_utils, 'cleanup_iso_image', autospec=True)
+    @mock.patch.object(redfish_utils, 'get_system', autospec=True)
+    def test_clean_up_instance_ramdisk(self, mock_system,
+                                       mock_cleanup_iso_image,
+                                       mock_cleanup_disk_image,
+                                       mock__eject_vmedia,
+                                       mock_get_boot_option,
+                                       mock_secure_boot):
+        managers = mock_system.return_value.managers
+
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=True) as task:
+            mock_get_boot_option.return_value = 'ramdisk'
+
+            task.driver.boot.clean_up_instance(task)
+
+            mock_cleanup_iso_image.assert_called_once_with(task)
+            mock_cleanup_disk_image.assert_called_once_with(
+                task, prefix='configdrive')
+            eject_calls = [
+                mock.call(task, managers, sushy.VIRTUAL_MEDIA_CD),
+                mock.call(task, managers, sushy.VIRTUAL_MEDIA_USBSTICK),
+            ]
+
+            mock__eject_vmedia.assert_has_calls(eject_calls)
+            mock_secure_boot.assert_called_once_with(task)
+
+    def test__insert_vmedia_anew(self):
 
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
@@ -828,19 +903,15 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
             mock_manager.virtual_media.get_members.return_value = [
                 mock_vmedia_cd, mock_vmedia_floppy]
 
-            mock_redfish_utils.get_system.return_value.managers = [
-                mock_manager]
-
             redfish_boot._insert_vmedia(
-                task, 'img-url', sushy.VIRTUAL_MEDIA_CD)
+                task, [mock_manager], 'img-url', sushy.VIRTUAL_MEDIA_CD)
 
             mock_vmedia_cd.insert_media.assert_called_once_with(
                 'img-url', inserted=True, write_protected=True)
 
             self.assertFalse(mock_vmedia_floppy.insert_media.call_count)
 
-    @mock.patch.object(redfish_boot, 'redfish_utils', autospec=True)
-    def test__insert_vmedia_already_inserted(self, mock_redfish_utils):
+    def test__insert_vmedia_already_inserted(self):
 
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
@@ -853,17 +924,13 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
             mock_manager.virtual_media.get_members.return_value = [
                 mock_vmedia_cd]
 
-            mock_redfish_utils.get_system.return_value.managers = [
-                mock_manager]
-
             redfish_boot._insert_vmedia(
-                task, 'img-url', sushy.VIRTUAL_MEDIA_CD)
+                task, [mock_manager], 'img-url', sushy.VIRTUAL_MEDIA_CD)
 
             self.assertFalse(mock_vmedia_cd.insert_media.call_count)
 
-    @mock.patch.object(redfish_boot, 'redfish_utils', autospec=True)
     @mock.patch('time.sleep', lambda *args, **kwargs: None)
-    def test__insert_vmedia_while_ejecting(self, mock_redfish_utils):
+    def test__insert_vmedia_while_ejecting(self):
 
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
@@ -882,17 +949,13 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
             mock_manager.virtual_media.get_members.return_value = [
                 mock_vmedia_cd]
 
-            mock_redfish_utils.get_system.return_value.managers = [
-                mock_manager]
-
             redfish_boot._insert_vmedia(
-                task, 'img-url', sushy.VIRTUAL_MEDIA_CD)
+                task, [mock_manager], 'img-url', sushy.VIRTUAL_MEDIA_CD)
 
             self.assertEqual(mock_vmedia_cd.insert_media.call_count, 2)
 
-    @mock.patch.object(redfish_boot, 'redfish_utils', autospec=True)
     @mock.patch('time.sleep', lambda *args, **kwargs: None)
-    def test__insert_vmedia_bad_device(self, mock_redfish_utils):
+    def test__insert_vmedia_bad_device(self):
 
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
@@ -904,17 +967,13 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
             mock_manager.virtual_media.get_members.return_value = [
                 mock_vmedia_floppy]
 
-            mock_redfish_utils.get_system.return_value.managers = [
-                mock_manager]
-
             self.assertRaises(
                 exception.InvalidParameterValue,
                 redfish_boot._insert_vmedia,
-                task, 'img-url', sushy.VIRTUAL_MEDIA_CD)
-            self.assertEqual(mock_redfish_utils.get_system.call_count, 1)
+                task, [mock_manager], 'img-url', sushy.VIRTUAL_MEDIA_CD)
 
     @mock.patch.object(redfish_boot, 'redfish_utils', autospec=True)
-    def test__eject_vmedia_everything(self, mock_redfish_utils):
+    def test_eject_vmedia_everything(self, mock_redfish_utils):
 
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
@@ -933,13 +992,13 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
             mock_redfish_utils.get_system.return_value.managers = [
                 mock_manager]
 
-            redfish_boot._eject_vmedia(task)
+            redfish_boot.eject_vmedia(task)
 
             mock_vmedia_cd.eject_media.assert_called_once_with()
             mock_vmedia_floppy.eject_media.assert_called_once_with()
 
     @mock.patch.object(redfish_boot, 'redfish_utils', autospec=True)
-    def test__eject_vmedia_specific(self, mock_redfish_utils):
+    def test_eject_vmedia_specific(self, mock_redfish_utils):
 
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
@@ -958,13 +1017,13 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
             mock_redfish_utils.get_system.return_value.managers = [
                 mock_manager]
 
-            redfish_boot._eject_vmedia(task, sushy.VIRTUAL_MEDIA_CD)
+            redfish_boot.eject_vmedia(task, sushy.VIRTUAL_MEDIA_CD)
 
             mock_vmedia_cd.eject_media.assert_called_once_with()
             self.assertFalse(mock_vmedia_floppy.eject_media.call_count)
 
     @mock.patch.object(redfish_boot, 'redfish_utils', autospec=True)
-    def test__eject_vmedia_not_inserted(self, mock_redfish_utils):
+    def test_eject_vmedia_not_inserted(self, mock_redfish_utils):
 
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
@@ -983,13 +1042,13 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
             mock_redfish_utils.get_system.return_value.managers = [
                 mock_manager]
 
-            redfish_boot._eject_vmedia(task)
+            redfish_boot.eject_vmedia(task)
 
             self.assertFalse(mock_vmedia_cd.eject_media.call_count)
             self.assertFalse(mock_vmedia_floppy.eject_media.call_count)
 
     @mock.patch.object(redfish_boot, 'redfish_utils', autospec=True)
-    def test__eject_vmedia_unknown(self, mock_redfish_utils):
+    def test_eject_vmedia_unknown(self, mock_redfish_utils):
 
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
@@ -1005,6 +1064,6 @@ class RedfishVirtualMediaBootTestCase(db_base.DbTestCase):
             mock_redfish_utils.get_system.return_value.managers = [
                 mock_manager]
 
-            redfish_boot._eject_vmedia(task)
+            redfish_boot.eject_vmedia(task)
 
             self.assertFalse(mock_vmedia_cd.eject_media.call_count)
