@@ -104,7 +104,8 @@ class RedfishManagementTestCase(db_base.DbTestCase):
                 # Asserts
                 fake_system.set_system_boot_options.assert_has_calls(
                     [mock.call(expected,
-                               enabled=sushy.BOOT_SOURCE_ENABLED_ONCE)])
+                               enabled=sushy.BOOT_SOURCE_ENABLED_ONCE),
+                     mock.call(mode=sushy.BOOT_SOURCE_MODE_BIOS)])
                 mock_get_system.assert_called_with(task.node)
                 self.assertNotIn('redfish_boot_device',
                                  task.node.driver_internal_info)
@@ -130,7 +131,8 @@ class RedfishManagementTestCase(db_base.DbTestCase):
 
                 fake_system.set_system_boot_options.assert_has_calls(
                     [mock.call(sushy.BOOT_SOURCE_TARGET_PXE,
-                               enabled=expected)])
+                               enabled=expected),
+                     mock.call(mode=sushy.BOOT_SOURCE_MODE_BIOS)])
                 mock_get_system.assert_called_with(task.node)
                 self.assertNotIn('redfish_boot_device',
                                  task.node.driver_internal_info)
@@ -157,7 +159,8 @@ class RedfishManagementTestCase(db_base.DbTestCase):
                     task, boot_devices.PXE, persistent=target)
 
                 fake_system.set_system_boot_options.assert_has_calls(
-                    [mock.call(sushy.BOOT_SOURCE_TARGET_PXE, enabled=None)])
+                    [mock.call(sushy.BOOT_SOURCE_TARGET_PXE, enabled=None),
+                     mock.call(mode=sushy.BOOT_SOURCE_MODE_BIOS)])
                 mock_get_system.assert_called_with(task.node)
 
                 # Reset mocks
@@ -263,15 +266,11 @@ class RedfishManagementTestCase(db_base.DbTestCase):
                                       shared=False) as task:
                 task.driver.management.set_boot_device(
                     task, boot_devices.PXE, persistent=True)
-                if vendor == 'SuperMicro':
-                    fake_system.set_system_boot_options.assert_has_calls(
-                        [mock.call(sushy.BOOT_SOURCE_TARGET_PXE,
-                                   enabled=expected),
-                         mock.call(mode=sushy.BOOT_SOURCE_MODE_BIOS)])
-                else:
-                    fake_system.set_system_boot_options.assert_has_calls(
-                        [mock.call(sushy.BOOT_SOURCE_TARGET_PXE,
-                                   enabled=expected)])
+
+                fake_system.set_system_boot_options.assert_has_calls(
+                    [mock.call(sushy.BOOT_SOURCE_TARGET_PXE,
+                               enabled=expected),
+                     mock.call(mode=sushy.BOOT_SOURCE_MODE_BIOS)])
 
                 # Reset mocks
                 fake_system.set_system_boot_options.reset_mock()
@@ -351,12 +350,6 @@ class RedfishManagementTestCase(db_base.DbTestCase):
 
     @mock.patch.object(redfish_utils, 'get_system', autospec=True)
     def test_set_boot_mode(self, mock_get_system):
-        boot_attribute = {
-            'target': sushy.BOOT_SOURCE_TARGET_PXE,
-            'enabled': sushy.BOOT_SOURCE_ENABLED_CONTINUOUS,
-            'mode': sushy.BOOT_SOURCE_MODE_BIOS,
-        }
-        fake_system = mock.Mock(boot=boot_attribute)
         fake_system = mock.Mock()
         mock_get_system.return_value = fake_system
         with task_manager.acquire(self.context, self.node.uuid,
@@ -381,12 +374,7 @@ class RedfishManagementTestCase(db_base.DbTestCase):
     @mock.patch.object(sushy, 'Sushy', autospec=True)
     @mock.patch.object(redfish_utils, 'get_system', autospec=True)
     def test_set_boot_mode_fail(self, mock_get_system, mock_sushy):
-        boot_attribute = {
-            'target': sushy.BOOT_SOURCE_TARGET_PXE,
-            'enabled': sushy.BOOT_SOURCE_ENABLED_CONTINUOUS,
-            'mode': sushy.BOOT_SOURCE_MODE_BIOS,
-        }
-        fake_system = mock.Mock(boot=boot_attribute)
+        fake_system = mock.Mock()
         fake_system.set_system_boot_options.side_effect = (
             sushy.exceptions.SushyError)
         mock_get_system.return_value = fake_system
@@ -399,27 +387,6 @@ class RedfishManagementTestCase(db_base.DbTestCase):
                 mode=boot_modes.UEFI)
             mock_get_system.assert_called_once_with(task.node)
 
-    @mock.patch.object(sushy, 'Sushy', autospec=True)
-    @mock.patch.object(redfish_utils, 'get_system', autospec=True)
-    def test_set_boot_mode_unsupported(self, mock_get_system, mock_sushy):
-        boot_attribute = {
-            'target': sushy.BOOT_SOURCE_TARGET_PXE,
-            'enabled': sushy.BOOT_SOURCE_ENABLED_CONTINUOUS,
-        }
-        fake_system = mock.Mock(boot=boot_attribute)
-        error = sushy.exceptions.BadRequestError('PATCH', '/', mock.Mock())
-        fake_system.set_system_boot_options.side_effect = error
-        mock_get_system.return_value = fake_system
-        with task_manager.acquire(self.context, self.node.uuid,
-                                  shared=False) as task:
-            self.assertRaisesRegex(
-                exception.UnsupportedDriverExtension,
-                'does not support set_boot_mode',
-                task.driver.management.set_boot_mode, task, boot_modes.UEFI)
-            fake_system.set_system_boot_options.assert_called_once_with(
-                mode=boot_modes.UEFI)
-            mock_get_system.assert_called_once_with(task.node)
-
     @mock.patch.object(redfish_utils, 'get_system', autospec=True)
     def test_get_boot_mode(self, mock_get_system):
         boot_attribute = {
@@ -1337,3 +1304,145 @@ class RedfishManagementTestCase(db_base.DbTestCase):
                 task.node.driver_internal_info['firmware_updates'])
             task.node.save.assert_called_once_with()
             mock_node_power_action.assert_called_once_with(task, states.REBOOT)
+
+    @mock.patch.object(redfish_utils, 'get_system', autospec=True)
+    def test_get_secure_boot_state(self, mock_get_system):
+        fake_system = mock_get_system.return_value
+        fake_system.secure_boot.enabled = False
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=True) as task:
+            response = task.driver.management.get_secure_boot_state(task)
+            self.assertIs(False, response)
+
+    @mock.patch.object(redfish_utils, 'get_system', autospec=True)
+    def test_get_secure_boot_state_not_implemented(self, mock_get_system):
+        # Yes, seriously, that's the only way to do it.
+        class NoSecureBoot(mock.Mock):
+            @property
+            def secure_boot(self):
+                raise sushy.exceptions.MissingAttributeError("boom")
+
+        mock_get_system.return_value = NoSecureBoot()
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=True) as task:
+            self.assertRaises(exception.UnsupportedDriverExtension,
+                              task.driver.management.get_secure_boot_state,
+                              task)
+
+    @mock.patch.object(redfish_utils, 'get_system', autospec=True)
+    def test_set_secure_boot_state(self, mock_get_system):
+        fake_system = mock_get_system.return_value
+        fake_system.secure_boot.enabled = False
+        fake_system.boot = {'mode': sushy.BOOT_SOURCE_MODE_UEFI}
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=True) as task:
+            task.driver.management.set_secure_boot_state(task, True)
+            fake_system.secure_boot.set_enabled.assert_called_once_with(True)
+
+    @mock.patch.object(redfish_utils, 'get_system', autospec=True)
+    def test_set_secure_boot_state_boot_mode_unknown(self, mock_get_system):
+        fake_system = mock_get_system.return_value
+        fake_system.secure_boot.enabled = False
+        fake_system.boot = {}
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=True) as task:
+            task.driver.management.set_secure_boot_state(task, True)
+            fake_system.secure_boot.set_enabled.assert_called_once_with(True)
+
+    @mock.patch.object(redfish_utils, 'get_system', autospec=True)
+    def test_set_secure_boot_state_boot_mode_no_change(self, mock_get_system):
+        fake_system = mock_get_system.return_value
+        fake_system.secure_boot.enabled = False
+        fake_system.boot = {'mode': sushy.BOOT_SOURCE_MODE_BIOS}
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=True) as task:
+            task.driver.management.set_secure_boot_state(task, False)
+            self.assertFalse(fake_system.secure_boot.set_enabled.called)
+
+    @mock.patch.object(redfish_utils, 'get_system', autospec=True)
+    def test_set_secure_boot_state_boot_mode_incorrect(self, mock_get_system):
+        fake_system = mock_get_system.return_value
+        fake_system.secure_boot.enabled = False
+        fake_system.boot = {'mode': sushy.BOOT_SOURCE_MODE_BIOS}
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=True) as task:
+            self.assertRaisesRegex(
+                exception.RedfishError, 'requires UEFI',
+                task.driver.management.set_secure_boot_state, task, True)
+            self.assertFalse(fake_system.secure_boot.set_enabled.called)
+
+    @mock.patch.object(redfish_utils, 'get_system', autospec=True)
+    def test_set_secure_boot_state_boot_mode_fails(self, mock_get_system):
+        fake_system = mock_get_system.return_value
+        fake_system.secure_boot.enabled = False
+        fake_system.secure_boot.set_enabled.side_effect = \
+            sushy.exceptions.SushyError
+        fake_system.boot = {'mode': sushy.BOOT_SOURCE_MODE_UEFI}
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=True) as task:
+            self.assertRaisesRegex(
+                exception.RedfishError, 'Failed to set secure boot',
+                task.driver.management.set_secure_boot_state, task, True)
+            fake_system.secure_boot.set_enabled.assert_called_once_with(True)
+
+    @mock.patch.object(redfish_utils, 'get_system', autospec=True)
+    def test_set_secure_boot_state_not_implemented(self, mock_get_system):
+        # Yes, seriously, that's the only way to do it.
+        class NoSecureBoot(mock.Mock):
+            @property
+            def secure_boot(self):
+                raise sushy.exceptions.MissingAttributeError("boom")
+
+        mock_get_system.return_value = NoSecureBoot()
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=True) as task:
+            self.assertRaises(exception.UnsupportedDriverExtension,
+                              task.driver.management.set_secure_boot_state,
+                              task, True)
+
+    @mock.patch.object(redfish_utils, 'get_system', autospec=True)
+    def test_reset_secure_boot_to_default(self, mock_get_system):
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=True) as task:
+            task.driver.management.reset_secure_boot_keys_to_default(task)
+            sb = mock_get_system.return_value.secure_boot
+            sb.reset_keys.assert_called_once_with(
+                sushy.SECURE_BOOT_RESET_KEYS_TO_DEFAULT)
+
+    @mock.patch.object(redfish_utils, 'get_system', autospec=True)
+    def test_reset_secure_boot_to_default_not_implemented(self,
+                                                          mock_get_system):
+        class NoSecureBoot(mock.Mock):
+            @property
+            def secure_boot(self):
+                raise sushy.exceptions.MissingAttributeError("boom")
+
+        mock_get_system.return_value = NoSecureBoot()
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=True) as task:
+            self.assertRaises(
+                exception.UnsupportedDriverExtension,
+                task.driver.management.reset_secure_boot_keys_to_default, task)
+
+    @mock.patch.object(redfish_utils, 'get_system', autospec=True)
+    def test_clear_secure_boot(self, mock_get_system):
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=True) as task:
+            task.driver.management.clear_secure_boot_keys(task)
+            sb = mock_get_system.return_value.secure_boot
+            sb.reset_keys.assert_called_once_with(
+                sushy.SECURE_BOOT_RESET_KEYS_DELETE_ALL)
+
+    @mock.patch.object(redfish_utils, 'get_system', autospec=True)
+    def test_clear_secure_boot_not_implemented(self, mock_get_system):
+        class NoSecureBoot(mock.Mock):
+            @property
+            def secure_boot(self):
+                raise sushy.exceptions.MissingAttributeError("boom")
+
+        mock_get_system.return_value = NoSecureBoot()
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=True) as task:
+            self.assertRaises(
+                exception.UnsupportedDriverExtension,
+                task.driver.management.clear_secure_boot_keys, task)
