@@ -119,6 +119,18 @@ SUSHY_SPEC = (
     'BOOT_SOURCE_TARGET_HDD',
     'BOOT_SOURCE_TARGET_CD',
     'BOOT_SOURCE_TARGET_BIOS_SETUP',
+    'CHASSIS_INDICATOR_LED_LIT',
+    'CHASSIS_INDICATOR_LED_BLINKING',
+    'CHASSIS_INDICATOR_LED_OFF',
+    'CHASSIS_INDICATOR_LED_UNKNOWN',
+    'DRIVE_INDICATOR_LED_LIT',
+    'DRIVE_INDICATOR_LED_BLINKING',
+    'DRIVE_INDICATOR_LED_OFF',
+    'DRIVE_INDICATOR_LED_UNKNOWN',
+    'INDICATOR_LED_LIT',
+    'INDICATOR_LED_BLINKING',
+    'INDICATOR_LED_OFF',
+    'INDICATOR_LED_UNKNOWN',
     'SYSTEM_POWER_STATE_ON',
     'SYSTEM_POWER_STATE_POWERING_ON',
     'SYSTEM_POWER_STATE_OFF',
@@ -143,6 +155,13 @@ SUSHY_SPEC = (
     'STATE_ABSENT',
     'VIRTUAL_MEDIA_CD',
     'VIRTUAL_MEDIA_FLOPPY',
+    'VIRTUAL_MEDIA_USBSTICK',
+    'APPLY_TIME_ON_RESET',
+    'TASK_STATE_COMPLETED',
+    'HEALTH_OK',
+    'HEALTH_WARNING',
+    'SECURE_BOOT_RESET_KEYS_TO_DEFAULT',
+    'SECURE_BOOT_RESET_KEYS_DELETE_ALL',
 )
 
 SUSHY_AUTH_SPEC = (
